#!/bin/sh 

export    STAGE=$1
export    SID=$2
export    VERSION=${3:-0.0.0.0}
export    FSROOT=${4:-/}
export    BIN_PATH="${FSROOT}/usr/pkg/bin"
export    SBIN_PATH="${FSROOT}/usr/pkg/sbin"
export    RCD_PATH="${FSROOT}/usr/pkg/etc/rc.d"
export    ETC_PATH="${FSROOT}/usr/pkg/etc"
export    MAN_PATH="${FSROOT}/usr/pkg/man"
MODULETYPE=

# private variables

# --------------------------------------------------------------------------------------------------
# SERVICE SID: system_scripts
# 
system_scripts_pre_package() {

	export stage_dir="${TMP_RPG_DIR}/${SID}"
	export templatesource=" ${SRC_ROOT}/switch/build/template/new_root.pax.bz2" 
	export snmp_conf_src="${SRC_ROOT}/switch/build/snmp_conf"
	export rpg_source="${SRC_ROOT}/tools/rpg_tools"
	export root_template="new_root.pax.bz2"
	export kernel_root="${SRC_ROOT}/../thirdparty/rn_netbsd/src/sys/arch/scout"


	export iscsi_conf_target="usr/pkg/etc"
	export snsd_conf_source="${SRC_ROOT}/switch/imgmt/iscsi/snsd"
	export saconf_source="${SRC_ROOT}/switch/imgmt/appmgmt/"
	export iscsibld_conf_source="${SRC_ROOT}/switch/iscsi/iscsibld/"
	export iscsi_script_source="${SRC_ROOT}/switch/iscsi/scripts"
	export snsd_conf="isnsservlist"
	export iscsibld_initiator_conf="iscsi_initiator_tp_db.txt"
	export iscsibld_tgt_conf="iscsi_target_tp_db.txt"



	export fc_portimage_source="${BUILD_ROOT}/port/figero_fc"
	export gige_portimage_source="${BUILD_ROOT}/port/figero_gige"
	export gige_iscsi_portimage_source="${BUILD_ROOT}/port/figero_gige_iscsi"
	export bm_portimage_source="${BUILD_ROOT}/port/figero_bm"
	export isw_portimage_source="${BUILD_ROOT}/port/figero_isw"
	export figero_portimage_target="tftpboot/figero/"
	export fc_portimages="fc.a*"
	export bm_portimages="bm.a*"
	export gige_portimages="fcip.*"
	export iscsi_portimages="iscsi.*"
	export isw_portimages="fc.isw*"

	export snmp_conf_dir="/usr/local/share/snmp"

        rm -rf ${stage_dir} 
	mkdir -p ${stage_dir}/etc/rc.d
	mkdir -p ${stage_dir}/usr/pkg/etc/rc.d

	cp ${SRC_ROOT}/switch/build/system/rc.local.mercury ${stage_dir}/etc/rc.local
	cp ${SRC_ROOT}/switch/build/system/rc.local.post ${stage_dir}/usr/pkg/etc/

	# package backplan script
	cp ${SRC_ROOT}/sysapi/backplaneconfig.sh ${stage_dir}/usr/pkg/etc/

	# SNMP config
	mkdir -p ${stage_dir}/${snmp_conf_dir}
        mkdir -p ${stage_dir}/usr/pkg/etc/rc.d
        cp ${snmp_conf_src}/snmp.conf ${stage_dir}/${snmp_conf_dir}/.
        cp ${snmp_conf_src}/snmpd.conf ${stage_dir}/${snmp_conf_dir}/.
        cp ${snmp_conf_src}/rc.snmpd ${stage_dir}/usr/pkg/etc/rc.d/snmpd
        cd ${stage_dir}/${snmp_conf_dir}
        chmod 755 ${stage_dir}/usr/pkg/etc/rc.d/snmpd

	# copy figero configuration file
        echo "copying figero configuration file"
        cd ${SRC_ROOT}/sysapi
        cp conf.figero* ${stage_dir}/etc
	cp ${SRC_ROOT}/switch/imgmt/iomctlr/rn_gbic.lst ${stage_dir}/etc
        cd ${stage_dir}/etc
        chmod 755 conf.figero*
        chmod 755 rn_gbic.lst

        mkdir -p ${stage_dir}/bin
        cd ${BUILD_ROOT}/cm/ppc/cli
        cp getmoduletype ${stage_dir}/bin
        chmod 755 getmoduletype

        # copy overseer configuration file
        echo "copying overseer configuration file"
        cd ${SRC_ROOT}/switch/imgmt/cha/od
        cp rn_od.conf ${stage_dir}/etc
        cp rc.overseer ${stage_dir}/usr/pkg/etc/rc.d/overseer
        cd ${stage_dir}/etc
        chmod 755 rn_od.conf
        chmod 755 ${stage_dir}/usr/pkg/etc/rc.d/overseer

        # copy openssl configuration file
        echo "copying openssl configuration file"
        cd ${SRC_ROOT}/switch/imgmt/objmgr
        cp openssl.cnf ${stage_dir}/etc
        cd ${stage_dir}/etc
        chmod 755 openssl.cnf

	# copy routed configuration file
        echo "copying routed configuration file"
        cd ${SRC_ROOT}/switch/imgmt/routed
        cp gateways  ${stage_dir}/etc
        cd ${stage_dir}/etc

        # copying ud
        cd ${SRC_ROOT}/switch/imgmt/cha/ud
        cp ud_conf.xml   ${stage_dir}/etc
        chmod 755        ${stage_dir}/etc/ud_conf.xml

        # copy ud_test.sh
        cd ${SRC_ROOT}/switch/imgmt/cha/ud
        cp ud_test.sh    ${stage_dir}/usr/pkg/etc/
        chmod 755        ${stage_dir}/usr/pkg/etc/

        # sd start script 
        cd ${SRC_ROOT}/switch/virt/sd
        cp rc.sd         ${stage_dir}/usr/pkg/etc/rc.d/sd
        chmod 755        ${stage_dir}/usr/pkg/etc/rc.d/sd

        # copy the rc.d start script
        mkdir -p ${stage_dir}/etc/rc.d
        cp ${SRC_ROOT}/switch/build/scripts/platform_start ${stage_dir}/etc/rc.d/.
        chmod 755 ${stage_dir}/etc/rc.d/platform_start

        # copy rpg tools
        mkdir ${stage_dir}/usr/sbin
        cp ${rpg_source}/rpg_extract.ppc ${stage_dir}/usr/sbin/rpg_extract

        # Create /var/log/messages
        mkdir -p ${stage_dir}/var/log
        #touch ${stage_dir}/var/log/messages
        #chmod 644 ${stage_dir}/var/log/messages

        # Create /var/log/authlog
        touch ${stage_dir}/var/log/authlog
        chmod 644 ${stage_dir}/var/log/authlog

        # Create /var/log/xferlog
        touch ${stage_dir}/var/log/xferlog
        chmod 644 ${stage_dir}/var/log/xferlog

        # Create /var/log/saslog
        touch ${stage_dir}/var/log/saslog
        chmod 644 ${stage_dir}/var/log/saslog

        # extract 'routed, rtquery' from root.pax.bz2 and 
        # stuff into rhapsody package
        cd ${stage_dir}
	
        pax -z -r -p e -f ${templatesource}  './sbin/routed'
        pax -z -r -p e -f ${templatesource}  './sbin/rtquery'
        pax -z -r -p e -f ${templatesource}  './etc/rc.conf'
        pax -z -r -p e -f ${templatesource}  './etc/rc.d/routed'

        # Run MAKEDEV all in /dev
        echo "copying/creating device files"
        mkdir -p ${stage_dir}/dev
        cp ${kernel_root}/MAKEDEV ${stage_dir}/dev/.
        chmod 777 ${stage_dir}/dev/MAKEDEV
        cd ${stage_dir}/dev; ./MAKEDEV all

        # copy snsd config file
        echo "copying iscsi config files"
        mkdir -p ${stage_dir}/${iscsi_conf_target}
        cp ${snsd_conf_source}/${snsd_conf} ${stage_dir}/${iscsi_conf_target}
        cp ${iscsibld_conf_source}/${iscsibld_initiator_conf} \
            ${stage_dir}/${iscsi_conf_target}
        cp ${iscsibld_conf_source}/${iscsibld_tgt_conf} ${stage_dir}/${iscsi_conf_target}
        cd ${stage_dir}/${iscsi_conf_target}; \
        for i in ${snsd_conf} ${iscsibld_initiator_conf} ${iscsibld_tgt_conf}; do
        done

        # copy etc scripts
        echo "copying etc scripts"
        mkdir -p ${stage_dir}/usr/pkg/etc
        cp ${BUILD_ROOT}/cm/ppc/etc/* ${stage_dir}/usr/pkg/etc/

        # loopback for switchboard for mercury
        printf "::1       localhost  \n" >> ${stage_dir}/etc/hosts
        printf "127.0.0.1 localhost  \n" >> ${stage_dir}/etc/hosts
        printf "# Warning: Don't change or remove the switchboard entry\n" >> ${stage_dir}/etc/hosts
        printf "127.0.0.1 switchboard\n" >> ${stage_dir}/etc/hosts

        # port stuff
        echo "setting up port components"
        mkdir -p ${stage_dir}/${figero_portimage_target}
        cd  ${stage_dir}/${figero_portimage_target}
        cp ${fc_portimage_source}/${fc_portimages} .
        cp ${gige_portimage_source}/${gige_portimages} .
        cp ${gige_iscsi_portimage_source}/${iscsi_portimages} .
        cp ${bm_portimage_source}/${bm_portimages} .
		cp ${isw_portimage_source}/${isw_portimages} .
        chmod 755 ${bm_portimages} ${gige_portimages} ${fc_portimages} ${isw_portimages}

	cd ${TMP_RPG_DIR}/${SID}
	pax -w -f ../${SID}.pax .
}   


system_scripts_post_install() {
	cd ${FSROOT}
	pax -r -p e -f ${SID}.pax
	rm -rf ${SID}.pax
	chmod -L 4755 ${FSROOT}/sbin/reboot

    MODULETYPE=`${FSROOT}/bin/getmoduletype`
	echo "Creating Flash device file."
	cd ${FSROOT}/dev; ./MAKEDEV flash1 flash2 flash3 flash4 flash5
    if [ $MODULETYPE = 34 ]; then
        echo "Creating links for DOC device."
        ln -f doc0a  part1
        ln -f rdoc0a rpart1
        ln -f doc0e  part2
        ln -f rdoc0e rpart2
        ln -f doc0f  part3
        ln -f rdoc0f rpart3
    fi

    if [ $MODULETYPE = 100 ]; then
        echo "Creating links for CF device."
        ln -f cf0a  part1
        ln -f rcf0a rpart1
        ln -f cf0e  part2
        ln -f rcf0e rpart2
        ln -f cf0f  part3
        ln -f rcf0f rpart3 
        ln -f cf0g  part4
        ln -f rcf0g rpart4 
        ln -f cf0h  part5
        ln -f rcf0h rpart5 
    fi

    # create a /var/log/messages file
    echo "#Install Comment. Please Ignore." >> ${FSROOT}/var/log/messages
    chmod 644 ${FSROOT}/var/log/messages
}

eval ${SID}_${STAGE}
