#!/bin/sh
#
#
#    Copyright (c) 1996-2000 Brocade Communications Systems, Inc.
#    All rights reserved.
#
#
# NAME
#      switchpost2.sh - POST phase II support script
# 
# AVAILABILITY
#      internal
# 
# DESCRIPTION
#      This  is  not  a  command.  It  is a script that manages the
#      POST(power on self test) phase II operations, which involves
#      mainly  in functional tests. The script is designed to oper-
#      ate across power cycles.
# 
# SEE ALSO
#      switchpost1(1d)
# 

#  Init variables
#
nPost=0			# number of POST executed
exit_status=0		# this script's exit status value
slot=1			# target slot to run POST (roy)
slot_message=""         # message related to slot information
_retcode=0

#  special temp file used for each test result
#
logFile=/tmp/post2Log

#
#  function to process trapped signal received. Upon entry, KILL the
#  child PID and output the abort message.
#
post_cleanup()
{
	#if [ $?child ]
	#then
	#	/bin/kill $child
	#fi
	#
	#  display ALL performed test result
	#
	_current_time=`/bin/date \+\%s`
	_date=`/bin/date`
	_duration=`/bin/expr $_current_time - $startTime`
	_minute=`/bin/expr $_duration / 60`
	_hour=`/bin/expr $_minute / 60`
	_sec=`/bin/expr $_duration % 60`
	_minute=`/bin/expr $_minute % 60`
	/bin/echo "" >> $logFile.$slot
	/bin/echo "POST2:$slot_message POST2 script has been ABORTED $_date took ($_hour:$_minute:$_sec)"
	/bin/echo "POST2:$slot_message POST2 script has been ABORTED $_date took ($_hour:$_minute:$_sec)" >> $logFile.$slot
	/bin/echo "POST2:$slot_message Completed $nPost Diagnostic tests."
	/bin/echo "POST2:$slot_message Completed $nPost Diagnostic tests." >> $logFile.$slot
	exit 1
}

perform_port_clear()
{
	port=0
	while [ $port -lt 16 ]
	do
	   portshowlog=`/usr/pkg/diagscripts/cmddir/diagportshow $port |grep Diag`
	   
		logdata=`/bin/echo $portshowlog  | /usr/bin/sed "s/\// /g"`
		logcnt=`/bin/echo $logdata | /usr/bin/wc -w`
		i=1
		while [ $i -lt $logcnt ]
		do
		   logdata2=`/bin/echo $logdata | /usr/bin/cut -d" " -f$i`   
		   if [ "$logdata2" = ":" ]
		   then
		       num=`/bin/expr $i + 1`
		       status=`/bin/echo $logdata | /usr/bin/cut -d" " -f$num`
		       if [ "$status" = "FAILED" ]  
		       then
			/usr/pkg/sbin/portdiagclear $port 2>&1 >> $logFile.$slot
		       fi
		   fi
		   i=`/bin/expr $i + 1`
		done	
	   
	   port=`/bin/expr $port + 1`
	done
	echo ""
}

#
#  Function to wait for exec_diag return and process the return status.
#
checkStatus()
{
	#  wait for current child to finish and get return status
	#
	#export child=$!
	#wait $child
	rval=$_retcode
	
	#  construct PASSED or FAILED msg from return value
	#  .  return value = 0 for PASSED
	#  .  return value != 0 for FAILED
	#
	case $rval in
	139 | 237 )
		echo " SKIPPED $1 due to Known Issue ($rval). Please run following command manually."
		echo "$*"
		echo " SKIPPED $1 due to Known Issue ($rval). Please run following command manually." >>  $logFile.$slot
		echo "$*" >>  $logFile.$slot
		;;
	0 )
		status=PASSED;;
	* )
		status=FAILED
		exit_status=`/bin/expr $exit_status + 1`;;
	esac

	#  compute return status (positive or negative value)
	#
	if [ $rval -gt 127 ]
	then
		rval=`/bin/expr $rval - 256`
	fi

	/bin/echo "POST2:$slot_message Returned status = $rval ($status)" >> $logFile.$slot
}

#
#  Function to print the test result
#
printPassFail()
{
   if [ $_retcode -eq 0 ]
   then
       /bin/echo "PASSED"
   else
       /bin/echo "FAILED"
   fi
}

# roy - remove the next 4 lines
#if [ $?FABOS_SLOTNO ]
#then
#	slot=$FABOS_SLOTNO
#fi

#
# source diagcommon
#
home="/usr/pkg/diagscripts/share"
testcmdhome="/usr/pkg/diagscripts/cmddir"
#util="diagcommon.sh"
ok=0
#for f in "./$util" "$FABOSHOME/share/$util" "$home/$util" ; do
#	if [ -r $f ] ; then
#		. $f
#		ok=1
#		break;
#	fi
#done
#if [ $ok -ne 1 ] ; then
#	errprint "Could not locate $util"
#	exit 3
#fi

#
# get sys info for multi blade
#
#multiBlade=`isMultiBlade`
#if [ $multiBlade = TRUE ]
#then
#     slot_message=" Slot $slot"
#     export syntax="$0 -slot [slot] essScript"
#else
#     export syntax="$0 essScript"
#fi

# cleanup the old log file
if [ -f $logFile.$slot ]
then
	/bin/rm $logFile.$slot
fi

#
#  display starting message
#
startTime=`/bin/date \+\%s`
_date=`/bin/date`
/bin/echo ""
/bin/echo "POST2:$slot_message Started running $_date"
/bin/echo "POST2:$slot_message Started running $_date" >> $logFile.$slot


#  export environment variable
#
DIAG_POST=0 ; export DIAG_POST

#
# Find exec_diag
#
#cmd=`commandPath exec_diag`

#
# Get list of ports for those diags that need them
#
#(roy)user_ports=`$cmd diagshow -use_bports 1 | grep "   OK" | /usr/bin/cut -d " " -f 2 | grep -v "\-\-" | sort -n | /usr/bin/xargs /bin/echo`
user_ports=1
# Make sure there is a port to run
#
if [ -z "$user_ports" ] ;
then
     /bin/echo "POST2:$slot_message ABORT - Nothing to test (NO active ports)"
     /bin/echo "POST2:$slot_message ABORT - Nothing to test (NO active ports)" >> $logFile.$slot
     exit 3 ;
else
     /bin/echo "POST2:$slot_message Testing User ports: $user_ports" >> $logFile.$slot
fi


#  export environment variable
#
DIAG_POST=1 ; export DIAG_POST
DCOMM_USR_FAILLIM=1 ; export DCOMM_USR_FAILLIM
#setdbg DIAG 1

#  setup signal trap to call cleanup() if the followings:
#	control/d entered at the same window
#	kill <pid> is entered
#
trap post_cleanup INT TERM KILL

#  reset Error on each port 
# 
#/bin/echo "POST2:$slot_message Running diagclearerror" >> $logFile.$slot
#$cmd diagclearerror $slot 2>&1 >> $logFile.$slot

# detect and handle bplb_mode
#bplb_mode=`config get diag.mode.bplb 2`
#if [ -z "$bplb_mode" ]
#then
#    bplb_mode=0
#fi
#if [ "$bplb_mode" != "0" ]
#then
#  echo "POST2:$slot_message BPLB mode is ON"
#  echo "POST2:$slot_message BPLB mode is ON" >> $logFile.$slot
#fi

#
# Start testing
#
#
#  clear any faulty marking for all the ports
#
perform_port_clear
sleep 2

#  perform Temp Show 
#
#nPost=`/bin/expr $nPost + 1`
#/bin/echo "" >> $logFile.$slot
#/bin/echo "POST2:$slot_message Test #$nPost - Running temperature show" >> $logFile.$slot
#printf "POST2:$slot_message Test #$nPost - Running temperature show ........... "
#$testcmdhome/tempshow.sh 1 2>&1 >> $logFile.$slot 
#_retcode=$?
#printPassFail
#checkStatus $testcmdhome/tempshow.sh 1

#  perform GBIC Show 
#
#nPost=`/bin/expr $nPost + 1`
#/bin/echo "" >> $logFile.$slot
#/bin/echo "POST2:$slot_message Test #$nPost - Running sfp show" >> $logFile.$slot
#printf "POST2:$slot_message Test #$nPost - Running sfp show ................... "
#$testcmdhome/sfpshow.sh 1 16 2>&1 >> $logFile.$slot 
#_retcode=$?
#printPassFail
#checkStatus $testcmdhome/sfpshow.sh 1 16

#  perform Power Supply Show 
#
#nPost=`/bin/expr $nPost + 1`
#/bin/echo "" >> $logFile.$slot
#/bin/echo "POST2:$slot_message Test #$nPost - Running power supply show" >> $logFile.$slot
#printf "POST2:$slot_message Test #$nPost - Running power supply show .......... "
#$testcmdhome/psshow.sh 1 2>&1 >> $logFile.$slot 
#_retcode=$?
#printPassFail
#checkStatus $testcmdhome/psshow.sh 1

#  perform Fan Show 
#
#nPost=`/bin/expr $nPost + 1`
#/bin/echo "" >> $logFile.$slot
#/bin/echo "POST2:$slot_message Test #$nPost - Running fan show" >> $logFile.$slot
#printf "POST2:$slot_message Test #$nPost - Running fan show ................... "
#$testcmdhome/fanshow.sh  1 0 2>&1 >> $logFile.$slot 
#_retcode=$?
#printPassFail
#checkStatus $testcmdhome/fanshow.sh  1

#  perform SEPROM Show 
#
#nPost=`/bin/expr $nPost + 1`
#/bin/echo "" >> $logFile.$slot
#/bin/echo "POST2:$slot_message Test #$nPost - Running seprom test" >> $logFile.$slot
#printf "POST2:$slot_message Test #$nPost - Running seprom test ................ "
#$testcmdhome/sepromtest.sh  1 0 2>&1 >> $logFile.$slot 
#_retcode=$?
#printPassFail
#checkStatus $testcmdhome/sepromtest.sh  1

#  perform ASIC Rev Show 
#
#nPost=`/bin/expr $nPost + 1`
#/bin/echo "" >> $logFile.$slot
#/bin/echo "POST2:$slot_message Test #$nPost - Running asic revision show" >> $logFile.$slot
#printf "POST2:$slot_message Test #$nPost - Running asic revision show ......... "
#$testcmdhome/asicshow.sh 1 2>&1 >> $logFile.$slot 
#_retcode=$?
#printPassFail
#checkStatus $testcmdhome/asicshow.sh 1

#  perform Cello Memory Test 
#
nPost=`/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST2:$slot_message Test #$nPost - Running cello memory test" >> $logFile.$slot
printf "POST2:$slot_message Test #$nPost - Running cello memory test ......... "
$testcmdhome/cellomt.sh 0 2>&1 >> $logFile.$slot 
_retcode=$?
printPassFail
checkStatus $testcmdhome/cellomt.sh 0

#  perform System Analyzer 
#
nPost=`/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST2:$slot_message Test #$nPost - Running cello port test" >> $logFile.$slot
printf "POST2:$slot_message Test #$nPost - Running cello port test ........... "
$testcmdhome/cellopt.sh  1000 2>&1 >> $logFile.$slot 
_retcode=$?
printPassFail
checkStatus $testcmdhome/cellopt.sh  1000

#  perform GMAC to Figero Bridge Test 
#
nPost=`/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST2:$slot_message Test #$nPost - Running gmac to bridge test" >> $logFile.$slot
printf "POST2:$slot_message Test #$nPost - Running gmac to bridge test ....... "
$testcmdhome/gmactst.sh  10000 1024 1 2>&1 >> $logFile.$slot 
_retcode=$?
printPassFail
checkStatus $testcmdhome/gmactst.sh  10000 1024 1 

#  perform Gbe Port Loopback 
#
nPost=`/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST2:$slot_message Test #$nPost - Running gbe port loopback test" >> $logFile.$slot
printf "POST2:$slot_message Test #$nPost - Running gbe port loopback test .... "
$testcmdhome/portlb_eth.sh 16  1000 0 2>&1 >> $logFile.$slot 
_retcode=$?
printPassFail
checkStatus $testcmdhome/portlb_eth.sh 16  1000 0

#  perform FC 1G Port Loopback 
#
nPost=`/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST2:$slot_message Test #$nPost - Running fc1g port loopback test" >> $logFile.$slot
printf "POST2:$slot_message Test #$nPost - Running fc1g port loopback test ... "
$testcmdhome/portlb_fc1.sh 16  1000 0 2>&1 >> $logFile.$slot 
_retcode=$?
printPassFail
checkStatus $testcmdhome/portlb_fc1.sh 16  1000 0

#  perform FC 2G Port Loopback 
#
nPost=`/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST2:$slot_message Test #$nPost - Running fc2g port loopback test" >> $logFile.$slot
printf "POST2:$slot_message Test #$nPost - Running fc2g port loopback test ... "
$testcmdhome/portlb_fc2.sh 16  1000 0 2>&1 >> $logFile.$slot 
_retcode=$?
printPassFail
checkStatus $testcmdhome/portlb_fc2.sh 16  1000 0

#  perform Gbe Spinsilk 
#
nPost=`/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST2:$slot_message Test #$nPost - Running gbe spinsilk" >> $logFile.$slot
printf "POST2:$slot_message Test #$nPost - Running gbe spinsilk .............. "
$testcmdhome/spinsilk_eth.sh 16  1000 4 2>&1 >> $logFile.$slot 
_retcode=$?
printPassFail
checkStatus $testcmdhome/spinsilk_eth.sh 16 1000 4

#  perform FC 1G Spinsilk 
#
nPost=`/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST2:$slot_message Test #$nPost - Running fc1g spinsilk" >> $logFile.$slot
printf "POST2:$slot_message Test #$nPost - Running fc1g spinsilk ............. "
$testcmdhome/spinsilk_fc1.sh 16  1000 4 2>&1 >> $logFile.$slot 
_retcode=$?
printPassFail
checkStatus $testcmdhome/spinsilk_fc1.sh 16 1000 4

#  perform FC 2G Spinsilk 
#
nPost=`/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST2:$slot_message Test #$nPost - Running fc2g spinsilk" >> $logFile.$slot
printf "POST2:$slot_message Test #$nPost - Running fc2g spinsilk ............. "
$testcmdhome/spinsilk_fc2.sh 16  1000 4 2>&1 >> $logFile.$slot 
_retcode=$?
printPassFail
checkStatus $testcmdhome/spinsilk_fc2.sh 16 1000 4

#  check test status of each port (must be RUN in fore ground)
# 
#/bin/echo "POST2:$slot_message Running diagshow" >> $logFile.$slot
#/bin/echo "POST2:$slot_message Running diagshow"
#$cmd diagshow --slot $slot -use_bports 1 -silent 1 >> $logFile.$slot 
#status=$?

#if [ $status -ne 0 ]
#then
#    exit_status=`/bin/expr $exit_status + 1`
#fi
#  display ALL performed test result
#
/bin/echo "" >> $logFile.$slot
/bin/echo "POST2:  ********** $slot_message POST Summary  **********" >> $logFile.$slot
/bin/echo "POST2:$slot_message Completed $nPost Diagnostic test:" >> $logFile.$slot

#  display exit msg and exit script
#
if [ $exit_status -ne 0 ]
then
    status=FAILED
else
    status=PASSED
fi
_current_time=`/bin/date \+\%s`
_date=`/bin/date`
_duration=`/bin/expr $_current_time - $startTime`
_minute=`/bin/expr $_duration / 60`
_hour=`/bin/expr $_minute / 60`
_sec=`/bin/expr $_duration % 60`
_minute=`/bin/expr $_minute % 60`
/bin/echo "POST2:$slot_message Script $status with exit status of $exit_status $_date took ($_hour:$_minute:$_sec)"
/bin/echo "POST2:$slot_message Script $status with exit status of $exit_status $_date took ($_hour:$_minute:$_sec)" >> $logFile.$slot
exit $exit_status








