#!/bin/ksh

#############################################################################
# Copyright (C) 2004 Brocade Communications Systems, Inc.
#############################################################################

#############################################################################

hex_to_dec () {
  number=`echo "$1" | tr '[a-f]' '[A-F]'`
  dec=`echo "ibase=16; $number" | bc`
  echo $dec
}

#############################################################################

if [ $# -lt 2 ]; then
  echo ""
  echo "USAGE: dump.sh <fig_num> <arm_num> [print_size 1-16376]"
  echo ""
  exit 0
fi

get_size=0
default_sz=8096
if [ $# -ge 3 ]
then
	get_size=1
fi

fig_num=$1
shift
arm_num=$1
shift

if [ $get_size -eq 1 ]
then
	print_sz=$1
	shift
fi

if [ "$print_sz" -eq "" ]
then
    print_sz=$default_sz
fi

if [ $print_sz -gt 16376 ]
then
    print_sz=16376
fi

head_adr=$((144637952+$arm_num*16384))
tail_adr=$(($head_adr+4))
buff_start=$(($head_adr+8))
buff_end=$(($buff_start+16376))

head_val=`/usr/pkg/diagscripts/figreg $fig_num $head_adr dump 4`
if [ $? -gt 0 ]
then
    echo "SRAM head addr ($head_adr) read for figero $fig_num failed "
    exit 0
fi

head_val=`hex_to_dec $head_val`

# if tail val is 4, then there was a wraparound
tail_val=`/usr/pkg/diagscripts/figreg $fig_num $tail_adr dump 4`
if [ $? -gt 0 ]
then
    echo "SRAM tail addr ($tail_adr) read for figero $fig_num failed "
    exit 0
fi

tail_val=`hex_to_dec $tail_val`

if [ $print_sz -lt $head_val ]
then
    start_addr=$(($buff_start+$head_val-$print_sz))
    /usr/pkg/diagscripts/dumpfigero $fig_num $start_addr $print_sz
else
    if [ $tail_val -eq 4 ]
    then
    	b1_sz=$(($print_sz-$head_val))
    	start_addr=$(($buff_end-$b1_sz))
    	/usr/pkg/diagscripts/dumpfigero $fig_num $start_addr $b1_sz
    fi
    /usr/pkg/diagscripts/dumpfigero $fig_num $buff_start $head_val
fi

exit 0

# End of file

