#!/bin/sh

#
# Copyright (c) 2005 Brocade Communications Systems, Inc.
# All rights reserved.
#
# Description:
#   <Insert Description Here>
#
#
# Copyright (c) 1997-2000 The NetBSD Foundation, Inc.
# All rights reserved.
#
# This code is derived from software contributed to The NetBSD Foundation
# by Luke Mewburn.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. All advertising materials mentioning features or use of this software
#    must display the following acknowledgement:
#        This product includes software developed by the NetBSD
#        Foundation, Inc. and its contributors.
# 4. Neither the name of The NetBSD Foundation nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
# ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#


#
#
# INTERNAL INSTRUCTIONS:
#
#   <Insert Instructions Here>
#
# Refer to rpg.xml for specific information on which stages you need to support.
#
#
# 
# STAGES                                                                 MOST-LIKELY REQUIRED FOR
# --------------------------------------------------------------------------------------------------
# startup        -  Startup  SID SERVICE, SERVICE-GROUP
# shutdown       -  Shutdown SID SERVICE, SERVICE-GROUP
# GLOBAL READ-ONLY variables
# --------------------------------------------------------------------------------------------------
# $STAGE      - See above 
# $SID        - Service ID (see RPG xml)
# $VERSION    - Version Identifier (see RPG xml) 
# $BIN_PATH   - (i.e. /usr/pkg/bin)
# $SBIN_PATH  - (i.e. /usr/pkg/sbin)
# $RCD_PATH   - (i.e. /usr/pkg/etc/rc.d)  // For backwards compatibility purposes 
# $ETC_PATH   - (i.e. /usr/pkg/etc)
# 
# HELPER FUNCTIONS
# --------------------------------------------------------------------------------------------------
#
# Note: Helper Functions do not take arguments in the event we migrate to a /etc/rc.d/ style
# methodology.
#
#    REQUIRED HELPER VARIABLES FOR HELPER FUNCTIONS
#    ---------------------------------------------------------
#    $_procpath - pathname (i.e. /usr/pkg/bin) 
#    $_progname - argv[0] of binary / listed in process table 
#    $_progargs - program arguments
#
# 
#
# startup__  : Starts Application
#    
#    if [ -f progname ] ; then
#       exec $_progname $_progargs
#    fi
#
# shutdown__ : Kills Application according to process name
#
#    ps | grep $_progname | kill -TERM  # NASTY
#   

# Define return codes here.
SUCCESS=0

# --------------------------------------------------------------------------------------------------

#
# SERVICE SID: sb
#

sb_startup() {
    _progpath="$BIN_PATH" 
    _progname="sb"
    _progargs=""
    eval startup__
}

sb_shutdown() {
    _progpath="$BIN_PATH" 
    _progname="sb"
    _progargs=""
    eval shutdown__
}

#
# SERVICE SID: objmgr
#

objmgr_startup() {
    _progpath="$BIN_PATH" 
    _progname="objmgr"
    _progargs=""
    eval startup__
}

objmgr_shutdown() {
    _progpath="$BIN_PATH" 
    _progname="objmgr"
    _progargs=""
    eval shutdown__
}


#
# SERVICE SID: evtmgr
#

evtmgr_startup() {
    _progpath="$BIN_PATH" 
    _progname="evtmgr"
    _progargs=""
    eval startup__
}

evtmgr_shutdown() {
    _progpath="$BIN_PATH" 
    _progname="evtmgr"
    _progargs=""
    eval shutdown__
}

#
# SERVICE SID: chassismgr
#

chassismgr_startup() {
    _progpath="$BIN_PATH" 
    _progname="chassisd"
    _progargs="-t"
    eval startup__
}

chassismgr_shutdown() {
    _progpath="$BIN_PATH" 
    _progname="chassisd"
    _progargs="-t"
    eval shutdown__
}

#
# SERVICE SID: chassispd
#

chassispd_startup() {

    _progpath="$BIN_PATH" 
    _progname="chassispd"

    _progargs="-d -e"

    eval startup__
}

chassispd_shutdown() {
    _progpath="$BIN_PATH" 
    _progname="chassispd"

    _progargs="-d -e"

    eval shutdown__
}

#
# SERVICE SID: diagd
#

diagd_startup() {
    _progpath="$BIN_PATH" 
    _progname="diagd"
    _progargs="-x -d"
    eval startup__
}

diagd_shutdown() {
    _progpath="$BIN_PATH" 
    _progname="diagd"
    _progargs="-x -d"
    eval shutdown__
}

#
# SERVICE SID: cpmgr
#

cpmgr_startup() {
    _progpath="$BIN_PATH" 
    _progname="cpmgr"
    _progargs="-D -r -x"
    eval startup__
}

cpmgr_shutdown() {
    _progpath="$BIN_PATH" 
    _progname="cpmgr"
    _progargs="-D -r -x"
    eval shutdown__
}

#
# COMMON FUNCTIONS
#
#
#


# 
# usage
#   Prints usage 
#
#

usage__()
{
    echo "Usage: $0 STAGE SID VERSION"
    exit 1
}

startup__()
{
    if [ -f "$_progpath/$_progname" ] ; then
	exec $_progpath/$_progname $_progargs
    else
        echo "Error: $_progname not found."
	exit 2
    fi
}

restart__()
{
    eval shutdown__
    eval startup__
}

shutdown__()
{
    # XXX : Performance Problem
    #    _pids=`eval check_process__ $_progpath/$_progname`
    #    wait_for_pids__ $_pids

    _pids=`eval check_process__ $_progname`
    wait_for_pids__ $_pids
}


#
# NetBSD: /etc/rc.subr modified
#

check_process__()
{
	_procname=$1
	echo $_procname
	if [ -z "$_procname" ]; then
		err 3 'USAGE: check_process procname'
	fi
	_procnamebn=${_procname##*/}
	_pref=
#	ps -ax -o 'pid,command' | while read _npid _arg0 _argv; do
	ps -ax -o 'pid,ucomm' | while read _npid _arg0 _argv; do
		case "$_npid" in
		    PID)
			continue ;;
		esac
		case "$_arg0" in
		    $_procname|$_procnamebn|${_procnamebn}:|"(${_procnamebn})"|/$_procname)
			echo -n "$_pref$_npid"
			_pref=" "
			;;
		esac
	done
}


#
# NetBSD: /etc/rc.subr modified
#

wait_for_pids__()
{
	_list=$*
	if [ -z "$_list" ]; then
		return
	fi
	_prefix=
	while true; do
		_nlist="";
		for _j in $_list; do
			if kill -9 $_j 2>/dev/null; then
				_nlist="${_nlist}${_nlist:+ }$_j"
			fi
		done
		if [ -z "$_nlist" ]; then
			break
		fi
		_list=$_nlist
		echo -n ${_prefix:-"Waiting for PIDS: "}$_list
		_prefix=", "

		### XXXX treacherous for OD

		sleep 1
	done
	if [ -n "$_prefix" ]; then
		echo "."
	fi
}


#
# COMMON EXECUTION STARTS HERE
# (i.e. main())
# 

export    STAGE=$1
export    SID=$2
export    VERSION=${3:-0.0.0.0}
export    FSROOT=${4:-/}
export    BIN_PATH="${FSROOT}/usr/pkg/bin"
export    SBIN_PATH="${FSROOT}/usr/pkg/sbin"
export    RCD_PATH="${FSROOT}/usr/pkg/etc/rc.d"
export    ETC_PATH="${FSROOT}/usr/pkg/etc"
export    MAN_PATH="${FSROOT}/usr/pkg/man"

if [ -z "$STAGE" ]; then
    usage__
fi

if [ -z "$SID" ]; then
    usage__
fi

# XXX Add: known STAGE check
# XXX Add: known SID   check
# XXX Add: function    check if possible? 

#
# Stage Workarounds :-)
#

# rc.d compat

if [ "$STAGE" = "start" ]; then
    STAGE=startup
fi

if [ "$STAGE" = "stop" ]; then
    STAGE=shutdown
fi

# base.xml equivalence translations

if [ "$STAGE" = "restore" ]; then
    STAGE=startup
fi

if [ "$STAGE" = "save" ]; then
    STAGE=shutdown
fi

eval \${SID}_\${STAGE}
