#
#    Copyright (c) 1996-2000 Brocade Communications Systems, Inc.
#    All rights reserved.
#
#    File name:   diagcommon.sh
#    Module name: diag/scripts
#
#    This file contains several useful functions used by the
#    diagnostics user command scripts.  They are stuck here
#    to save some disk image space.  To optimize execution time
#    copy this file into each of the command scripts instead.
#

_default_home="/usr/pkg/diagscripts"                 # FABOSHOME default
_cfg_cmd="configdb.sh"		      # config program
_def_slot=1
_result1=0  			#make _result1 global
_display_name="unknown test"
# definitions that must match src/include/config/resource.h 
# define Resource* (line 68-line 74)
INTEGER=2			      # config modes
STRING=5
HEX=6
# definitions that must match src/include/em/em_if.h ledState_e
LED_DEFAULT=0
LED_SOLID_OFF=1
LED_SOLID_ON=2
LED_FAST_BLINK=3
LED_SLOW_BLINK=4
LED_CS_FAIL=5
LED_CS_PASS=6
LED_INIT_VARS=7
##################
# Utilities
#

# error
# $1 error string
err () {
	/bin/echo "" >&2
	/bin/echo "Error -- $1" >&2
	if [ -n "$syntax" ] ; then
		eval /bin/echo Syntax: $syntax >&2
	fi
}

# commandPath
#
# Get full path to FABOS command
# $1 command name
#
commandPath () {
	# First try fabos/sbin/command
	if [ "$FABOSHOME" = "" ] ; then
		_cmd="$_default_home/sbin/$1"
	else
		_cmd="$FABOSHOME/sbin/$1"
	fi
	if [ -x $_cmd ] ; then
		/bin/echo $_cmd
		return 0
	fi

	# No luck -- try fabos/bin/command
	if [ "$FABOSHOME" = "" ] ; then
		_cmd="$_default_home/bin/$1"
	else
		_cmd="$FABOSHOME/bin/$1"
	fi
	if [ -x $_cmd ] ; then
		/bin/echo $_cmd
		return 0
	fi

	# Still no luck try fabos/command
	if [ "$FABOSHOME" = "" ] ; then
		_cmd="$_default_home/$1"
	else
		_cmd="$FABOSHOME/$1"
	fi
	if [ -x $_cmd ] ; then
		/bin/echo $_cmd
		return 0
	fi

	# Still no luck try fabos/share
	if [ "$FABOSHOME" = "" ] ; then
		_cmd="$_default_home/share/$1"
	else
		_cmd="$FABOSHOME/share/$1"
	fi
	
	if [ -x $_cmd ] ; then
		/bin/echo $_cmd
		return 0
	fi

	# Still no luck try fabos/factory
	if [ "$FABOSHOME" = "" ] ; then
		_cmd="$_default_home/factory/$1"
	else
		_cmd="$FABOSHOME/factory/$1"
	fi
	if [ -x $_cmd ] ; then
		/bin/echo $_cmd
		return 0
	fi

	# Last but not least try plain old command.
	_cmd="$1"
	if [ -x $_cmd ] ; then
		/bin/echo $_cmd
		return 0
	fi

	# Ok we give up now.
	err "Could not find: $_cmd"
	return 3

}

# setConfig()
#
# Set configuration variable value
# $1 = config string to set
# $2 = config mode
# $3 = new value
#
setConfig () {
	_cmd=`commandPath $_cfg_cmd`
	if [ $? != 0 ] ; then exit 3 ; fi
	if { $_cmd set "$1" "$2" "$3"; } ; then
		return 0
	else
		err "setConfig failed"
		exit 3
	fi
}

# commitConfig()
#
# Push configuration changes to kernel.
#  -- no inputs required.
#
commitConfig () {
	_cmd=`commandPath $_cfg_cmd`
	if [ $? != 0 ] ; then exit 3 ; fi
	if { $_cmd commit; } ; then
	    /bin/echo "Config commit Succeeded" >&2
	    return 0
	else
	    err "commitConfig failed"
	    exit 3
	fi
}

# updateConfig() 
# 
# Commit configuration changes to NV storage. 
#  -- no inputs required. 
# 
updateConfig () { 
	_cmd=`commandPath $_cfg_cmd` 
	if [ $? != 0 ] ; then exit 3 ; fi
	for _try in 1 2 3 4 5 6 7 8 9 10; do
	    if { $_cmd update 0 0 2>/dev/null | /usr/bin/grep --quiet "done" ; } ; then 
		/bin/echo "Config update Succeeded" >&2
		return 0 
	    fi
	    if [ $_try -ne 10 ] ; then
		/bin/echo "Config update failed, retrying" >&2
		/bin/sleep 3
	    fi
	done;

	# Should not get here
	err "Config update failed" 
      	exit 3 
}
 
# ConfigSetCheck()
#
# Check if a config variable has been set
# $1 = config string to set
# $2 = config mode
#
ConfigSetCheck () {
	_cmd=`commandPath $_cfg_cmd`
	if [ $? != 0 ] ; then exit 3 ; fi
	_val=`$_cmd get "$1" "$2" 2>/dev/null`
	if [ -z "$_val" ] ; then
		return 1
	fi
	return 0
}

# getConfig()
#
# Set configuration variable value
# $1 = config string to set
# $2 = config mode
# $3 = default
#
getConfig () {
	_cmd=`commandPath $_cfg_cmd`
	if [ $? != 0 ] ; then exit 3 ; fi
	_val=`$_cmd get "$1" "$2" 2>/dev/null`
	if [ -z "$_val" ] ; then
		_val="$3"
	fi

	/bin/echo $_val
	return 0
}

# testConfig()
#
# Set configuration variable value
# $1 = config string to test
# $2 = config mode
#
testConfig () {
	_cmd=`commandPath $_cfg_cmd`
	if [ $? != 0 ] ; then exit 3 ; fi
	_val=`$_cmd get "$1" $2 2>/dev/null`
	if [ -z "$_val" ] ; then
		/bin/echo "0"
	else
		/bin/echo "1"
	fi
	return 0
}

# checkForShow()
#
# Display current setting and bail if this is a show
# command.  Also check for -inc and increment the current
# setting but only if the config_mode is not STRING and
# the value is not boolean.
#
# $1 = config_name
# $2 = config_string
# $3 = config_mode
# $4 = config_default
# $5 = argument to check. (must be last)

checkForShow () {
	_s=`/bin/expr "$5" : "[-]*show"`
	if { [ -z "$5" ] || [ "0" -ne "$_s" ] ; } ; then
		_val=`getConfig $2 $3 $4`
		if [ $? != 0 ] ; then exit 3 ; fi
		if { [ -n "$bool_true" ] && [ -n "$bool_false" ] ; } ; then
			if [ "$_val" -ne 0 ] ; then
				_res=$bool_true
			else
				_res=$bool_false
					fi
			/bin/echo "$1 is $_val ($_res)".
		else
			/bin/echo "$1 is $_val".
		fi

		exit 0
	else
		_s=`/bin/expr "$5" : "[-]*inc"`
		if { [ "$3" != "$STRING" ] && [ "0" -ne "$_s" ] && \
				 [ -z "$bool_true" ] && [ -z "$bool_false" ] ; }
		then
			_val=`getConfig $2 $3 $4`
			if [ $? != 0 ] ; then exit 3 ; fi
			_val=`/bin/expr $_val + 1`
			setConfig $2 $3 $_val
			/bin/echo "$1 is now ${_val}."
			exit 0
		fi
		return 0
	fi
}

# getValue()
#
# Converts input string into number or generates an
# error.  Special keywords [-]enable (1) [-]disable (0)
# [-]on (1) and [-off] (0) are also supported for
# boolean conditions
#
# $1 = parameter to check

getValue () {

	_s=`/bin/expr "$1" : "[-]*enable"`
	if [ "0" -ne "$_s" ]; then
		/bin/echo "1"
		return 0
	fi

	_s=`/bin/expr "$1" : "[-]*on"`
	if [ "0" -ne "$_s" ]; then
		/bin/echo "1"
		return 0
	fi

	_s=`/bin/expr "$1" : "[-]*disable"`
	if [ "0" -ne "$_s" ]; then
		/bin/echo "0"
		return 0
	fi

	_s=`/bin/expr "$1" : "[-]*off"`
	if [ "0" -ne "$_s" ]; then
		/bin/echo "0"
		return 0
	fi

	_n=`/bin/echo "$1" | \
		/usr/bin/wc -c | \
		/usr/bin/tr -s " " " " | \
		/usr/bin/cut -d" " -f2`
	_n=`/bin/expr $_n - 1`
	_s=`/bin/expr "$1" : "[-][0-9]*"`
	_t=`/bin/expr "$1" : "[0-9]*"`
	if [ "$_n" -eq "$_s" -o  "$_n" -eq "$_t" ]; then
		/bin/echo $1
		return 0
	fi

	err "Invalid parameter $1"
	/bin/echo "-1"
	exit 3
}

nameForDisplay () {

	if [ "$1" = "voltagemargin.sh" ] ; then _display_name="voltagemargin" ; fi 
	if [ "$1" = "voltshow.sh" ] ; then _display_name="voltage_show" ; fi 
	if [ "$1" = "asicshow.sh" ] ; then _display_name="asic_revision_show" ; fi 
	if [ "$1" = "tempshow.sh" ] ; then _display_name="temperature_show" ; fi 
	if [ "$1" = "sfpshow.sh" ] ; then _display_name="sfp_show" ; fi 
	if [ "$1" = "psshow.sh" ] ; then _display_name="power_supply_show" ; fi 
	if [ "$1" = "sepromtest.sh" ] ; then _display_name="seprom_test" ; fi 
	if [ "$1" = "setfanspeed.sh" ] ; then _display_name="set_fan_speed" ; fi 
	if [ "$1" = "fanshow.sh" ] ; then _display_name="fan_show" ; fi 
	if [ "$1" = "nvTest.sh" ] ; then _display_name="nv_ram_test" ; fi 
	if [ "$1" = "cflashTest.sh" ] ; then _display_name="compact_flash_test" ; fi 
	if [ "$1" = "bflashTest.sh" ] ; then _display_name="boot_flash_test" ; fi 
	if [ "$1" = "figmem.sh" ] ; then _display_name="figero_port_memory_test" ; fi 
	if [ "$1" = "figarm.sh" ] ; then _display_name="figero_arm_memory_test" ; fi 
	if [ "$1" = "cellomt.sh" ] ; then _display_name="cello_memory_test" ; fi 
	if [ "$1" = "cellopt.sh" ] ; then _display_name="cello_port_test" ; fi 
	if [ "$1" = "gmactst.sh" ] ; then _display_name="gmac_to_bridge_test" ; fi 
	if [ "$1" = "portlb_eth.sh" ] ; then _display_name="gbe_port_loopback_test" ; fi 
	if [ "$1" = "portlb_fc1.sh" ] ; then _display_name="fc1g_port_loopback_test" ; fi 
	if [ "$1" = "portlb_fc2.sh" ] ; then _display_name="fc2g_port_loopback_test" ; fi 
	if [ "$1" = "spinsilk_eth.sh" ] ; then _display_name="gbe_spinsilk_test" ; fi 
	if [ "$1" = "spinsilk_fc1.sh" ] ; then _display_name="fc1g_spinsilk_test" ; fi 
	if [ "$1" = "spinsilk_fc2.sh" ] ; then _display_name="fc2g_spinsilk_test" ; fi 
	if [ "$1" = "mgmtTest.sh" ] ; then _display_name="management_port_test" ; fi 	
}

##################################
# NAME
#    enableSlotProc - enable /proc/fabos/blade/slot entries
#
# SYNOPSIS
#    enableSlotProc slot_no
#
# DESCRIPTION
#    
#    1) check slot existence
#    2) get proc entries by calling debugentryon
#    3) varify the exection by checking its return status
#	if fail, exit and tell the user to relinguish others
#	if success, continue
#
# OPERANDS
#    slot_no
##################################
#function 
enableSlotProc() {
	if [ ! -e /proc/usr/pkg/diagscripts/blade/$1 ] ; then
	    err "Slot: $slot not found"
	    exit 3
	fi
	debugentryon --slot $1 > /dev/null 2>&1
	if [ "0" -ne "$?" ] ; then
	    if [ `isMultiBlade` = TRUE ]
	    then
		/bin/echo "Slot$1: not enough proc entires, relinguish by running "debugEntryOff" first"
		/bin/echo "       Usage: debugEntryOff --slot x"
	    else
		/bin/echo "Not enough proc entires, relinguish by running "debugEntryOff" first"
		/bin/echo "       Usage: debugEntryOff"
	    fi
	      exit 3
	 fi
}

##################################
# NAME
#    disableSlotProc - disable /proc/fabos/blade/slot entries
#
# SYNOPSIS
#    disableSlotProc slot_no
#
# DESCRIPTION
#    
#    release previously enabled proc entries.
#
# OPERANDS
#    slot_no
##################################
#function 
disableSlotProc() {
	 # relinguish the proc entries
	 debugentryoff --slot $1 > /dev/null 2>&1
}

#
# Begin burnin script support
# Bill Lewis 7/24/2001
#
##################################
#PRIVATE FUNCTIONS
##################################
##################################
# This function import_burnin_variables() is intended for
# internal use only. It ensures that each PARAMDEF entry exists
# in the config database.
#
# It gets the variable name from field 2 of the file, and the 
# default value from field 3. If the item does not exist, then it is 
# created, and given the default value. Otherwise, the config 
# database value is left untouched.
# $1 = PARAMDEF to parse
# space seperated list
#  field 1 = "PARAMDEF"
#  field 2 = varaible name
#  field 3 = default value
#  field 4 = mode: $INTEGER, $STRING
#  field 5 = minimum value
#  field 6 = maximum value
#  field 7 = description

##################################
import_burnin_variables()
{
	_param_list=`get_param_list`
	_param_list_with_cr=`get_param_list_with_cr`
	_num_params=`/bin/echo $_param_list | \
				 /usr/bin/tr -s " " "_" | \
				 /usr/bin/tr -s "@" " " | \
				 /usr/bin/wc -w`
	export _num_params
	config_list=`get_config_list`
	_num=1
	while [ $_num -le $_num_params ]
	do
		#_param=`/bin/echo $_param_list | /usr/bin/cut -d"@" -f$_num`
		_param=`get_param_line $_num`
		_var_name=`/bin/echo $_param | /usr/bin/cut -d" " -f2`
		_dflt_val=`/bin/echo $_param | /usr/bin/cut -d" " -f3`
		_mode_val=`/bin/echo $_param | /usr/bin/cut -d" " -f4`
		_cur_val="`get_config_entry $_var_name`"
		if [ -z "$_cur_val" ]
		then
			_cur_val=$_dflt_val
			setConfig diag.$MyName.$_var_name $_mode_val "$_dflt_val"
		fi
		burninMessage "$_var_name=\""$_cur_val\"
		export `eval /bin/echo $_var_name`="`eval /bin/echo $_cur_val`"
		_num=`/bin/expr $_num + 1`
	done
}

##################################
# This function valide_integer() is an internal only function.
# It determines if an integer is between two values. It
# expects the first parameter to be the value in question. The
# second value to be the minimum acceptable value, and the
# third value to be the maximum acceptable value. The min and
# max values are considered valid.
# $1 = value to test
# $2 = minimum acceptable value
# $3 = maximum acceptable value
##################################
validate_integer()
{
	_pass=TRUE
	_x=`/bin/echo $1 | /usr/bin/sed "s/[0-9]//g"`
	if [ "$_x" != "" ]
	then
		_pass=NOTNUMBER
	else	
		if [ $1 -le 2147483647 ]
		then
			if [ "$2" != "NA" ]
			then
				_x=`/bin/echo $2 | /usr/bin/sed "s/[0-9]//g"`
				if [ "$_x" != "" ]
				then
					_pass=MINNOTNUMBER
				else
					if [ $1 -lt $2 ]
					then
						_pass=LESSTHANMIN
					fi
				fi
			fi

			if [ "$3" != "NA" ]
			then
				_x=`/bin/echo $3 | /usr/bin/sed "s/[0-9]//g"`
				if [ "$_x" != "" ]
				then
					_pass=MAXNOTNUMBER
				else
					if [ $1 -gt $3 ]
					then
						_pass=GREATERTHANMAX
					fi
				fi

			fi
		else
			_pass=GREATERTHANMAX

		fi
	fi
	/bin/echo $_pass
}


##################################
# This function diagsetcycledefault() is for library use only.
# It processes each PARAMDEF variable, and sets each variable
# to the default value for each parameter. The config database
# is updated only if a value is modified values. If values are 
# not found in the config database, entries are inserted with 
# the default values.
#
# The format of the PARAMDEF is inturpeted as follows:
# $1 = space seperated PARAMDEF
# Field Description
# 1     PARAMDEF
# 2     Variable name
# 3     Default value for named variable
# 4     Mode of the variable ($INTEGER, $STRING)
# 5     Minimum valid value of named variable (NA if not applicable)
# 6     Maximum valid value of named variable (NA if not applicable)
# 7     Description of the effect of the named variable
#
# The configdata base is queried to determine 
# the current value. If the entry does not exist, then an 
# entry is created with the default value. The user is queried 
# for modification and the value is updated if it is not the default.
##################################
diagsetcycledefault()
{
	/bin/echo "DEFAULT	- KEYWORD	: COMMENT"
	_num=1
	while [ $_num -le $_num_params ]
	do
		# _param=`/bin/echo $_param_list | /usr/bin/cut -d"@" -f$_num`
		_param=`get_param_line $_num`
		_var_name=`/bin/echo $_param | /usr/bin/cut -d" " -f2`
		_dflt_val=`/bin/echo $_param | /usr/bin/cut -d" " -f3`
		_mode_val=`/bin/echo $_param | /usr/bin/cut -d" " -f4`
		_cmnt=`/bin/echo $_param     | /usr/bin/cut -d" " -f7-`
		_cur_val="`get_config_entry $_var_name`"
		if [ $_dflt_val != "$_cur_val" ]
		then
			/bin/echo replacing $_cur_val with default $_dflt_val
			setConfig diag.$MyName.$_var_name $_mode_val "$_dflt_val"
			_modified=TRUE
		fi
		/bin/echo " $_dflt_val	- $_var_name	: $_cmnt "
		_num=`/bin/expr $_num + 1`
	done
	config_list=`get_config_list`
}

##################################
# This function diagsetcycleshow() is for library use only.
# It processes each PARAMDEF variable, and outputs the current
# setting for each variable. The config database is used to 
# get the current setting. If values are not found in the config
# database, the default value is output.
#
# The format of the PARAMDEF is inturpeted as follows:
# $1 = space seperated PARAMDEF
# Field Description
# 1     PARAMDEF
# 2     Variable name
# 3     Default value for named variable
# 4     Mode of the variable ($INTEGER, $STRING)
# 5     Minimum valid value of named variable (NA if not applicable)
# 6     Maximum valid value of named variable (NA if not applicable)
# 7     Description of the effect of the named variable
##################################
diagsetcycleshow()
{
	/bin/echo "CURRENT	- KEYWORD    		: DEFAULT "
	_num=1
	while [ $_num -le $_num_params ]
	do
		#_param=`/bin/echo $_param_list | /usr/bin/cut -d"@" -f$_num`
		_param=`get_param_line $_num`
		_var_name=`/bin/echo $_param | /usr/bin/cut -d" " -f2`
		_dflt_val=`/bin/echo $_param | /usr/bin/cut -d" " -f3`
		_mode_val=`/bin/echo $_param | /usr/bin/cut -d" " -f4`
		_cmnt=`/bin/echo $_param     | /usr/bin/cut -d" " -f7-`
		_cur_val="`get_config_entry $_var_name`"
		if [ -z "$_cur_val" ]
		then
			_cur_val=$_dflt_val
		fi
		/bin/echo " $_cur_val	- $_var_name    	: $_dflt_val "
		_num=`/bin/expr $_num + 1`
	done
}

##################################
# This function diagsetcycleinteractive() is for library use only.
# It processes each PARAMDEF variable, and asks user for new 
# value for each parameter. The config database is updated with
# the modified values. If values are not found in the config 
# database, entries are inserted with the default values.
#
# The format of the PARAMDEF is inturpeted as follows:
# $1 = space seperated PARAMDEF
# Field Description
# 1     PARAMDEF
# 2     Variable name
# 3     Default value for named variable
# 4     Mode of the variable ($INTEGER, $STRING)
# 5     Minimum valid value of named variable (NA if not applicable)
# 6     Maximum valid value of named variable (NA if not applicable)
# 7     Description of the effect of the named variable
#
# The configdata base is queried to determine 
# the current value. If the entry does not exist, then an 
# entry is created with the default value. The user is queried 
# for modification and the value is updated based on the response.
#
# If the value is outside of the min/max limits, the user is 
# re-prompted for the value. If there have been three unsuccessful 
# attempts to modify the value, then the default value is taken, 
# and the next file is processed.
##################################
diagsetcycleinteractive()
{
#    echo "_num_params = $_num_params"
#	echo "$_param_list"
#    if [ -f "test.log" ]
#	then 
#	  rm "test.log"
#	fi
	/bin/echo "CURRENT - KEYWORD         	- DEFAULT , COMMENT: "
	_num=1
    
	while [ $_num -le $_num_params ]
	do
		#_param=`/bin/echo $_param_list | /usr/bin/cut -d"@" -f$_num`
        _param=`get_param_line $_num`
		_var_name=`/bin/echo $_param | /usr/bin/cut -d" " -f2`
		_dflt_val=`/bin/echo $_param | /usr/bin/cut -d" " -f3`
		_mode_val=`/bin/echo $_param | /usr/bin/cut -d" " -f4`
		_cmnt=`/bin/echo $_param     | /usr/bin/cut -d" " -f7-`
		_cur_val="`get_config_entry $_var_name`"
		if [ -z "$_cur_val" ]
		then
			_cur_val=$_dflt_val
			_in_config=FALSE
		else
			_in_config=TRUE
		fi
		_ok=FALSE
		_attempts=0
		while [ $_attempts -lt 3 -a $_ok != TRUE ]
		do
			/bin/echo -n " $_cur_val	- $_var_name    	- $_dflt_val , $_cmnt: "
			read _answer
			_attempts=`/bin/expr $_attempts + 1`
			if [ -z "$_answer" ] 
			then
				if [ "$_in_config" = "FALSE" ]
				then
					setConfig diag.$MyName.$_var_name $_mode_val $_dflt_val
					_modified=TRUE
				fi
				_ok=TRUE
			else
				if [ $_mode_val = $INTEGER ]
				then
					_min_val=`/bin/echo $_param  | /usr/bin/cut -d" " -f5`
					_max_val=`/bin/echo $_param  | /usr/bin/cut -d" " -f6`
					_ok=`validate_integer $_answer $_min_val $_max_val`		
					if [ $_ok != TRUE ]
					then
						/bin/echo $_ok
						if [ $_attempts -eq 3 ]
						then
							/bin/echo " ERROR - Wrong value entered three times, using default value $_dflt_val"
							_ok=TRUE
							_answer=$_dflt_val
						else
							if [ "$_max_val" = "NA" ]
							then
								/bin/echo " ERROR - Invalid value. Please specify a value between $_min_val and 2147483647 inclusive"							
							else
								/bin/echo " ERROR - Invalid value. Please specify a value between $_min_val and $_max_val inclusive"
							fi
						fi
					fi
				else
					_ok=TRUE
				fi
				
				if [ $_ok = TRUE ]
				then
					/bin/echo " Saving new value: $_answer"
					setConfig diag.$MyName.$_var_name $_mode_val "$_answer"
					_modified=TRUE
				fi
			fi
		done
		_num=`/bin/expr $_num + 1`
	done
	config_list=`get_config_list`
}

##################################
# This function diagsetcycleparameters() is for library use only.
# It processes a list of arguments from the command line, and 
# updates the config database if the PARAMDEF exists for the 
# keyword/value pair received from the command line. The config
# database is updated with the modified values. If values are
# not found in the config database and the entry appears in the
# PARAMDEF for ther script, then entries are inserted in the
# config databasewith the specified values.
#
# This function requires the arguments top be a list of files to process.
#
# The format of the PARAMDEF is inturpeted as follows:
# $1 = space seperated PARAMDEF
# Field Description
# 1     PARAMDEF
# 2     Variable name
# 3     Default value for named variable
# 4     Mode of the variable ($INTEGER, $STRING)
# 5     Minimum valid value of named variable (NA if not applicable)
# 6     Maximum valid value of named variable (NA if not applicable)
# 7     Description of the effect of the named variable
#
# If the value is outside of the min/max limits, the update will not 
# proceed.
##################################
diagsetcycleparameters()
{
	_parameters=FALSE
	i=1
	while [ "$i" -le $_num_env ]
	do
		i=`/bin/expr $i + 1`
		new_param=`/bin/echo $_env | /usr/bin/cut -d"@" -f$i`
		_key=`/bin/echo $new_param | /usr/bin/cut -d" " -f1`
		_val=`/bin/echo $new_param | /usr/bin/cut -d" " -f2-`
		old_param=`get_param_list | /usr/bin/grep -w $_key`
		if [ ! -z "$old_param" ]
		then
			_dflt_val=`/bin/echo $old_param | /usr/bin/cut -d" " -f3`
			_mode_val=`/bin/echo $old_param | /usr/bin/cut -d" " -f4`
			if [ $_mode_val = $INTEGER ]
			then
				_min_val=`/bin/echo $old_param  | /usr/bin/cut -d" " -f5`
				_max_val=`/bin/echo $old_param  | /usr/bin/cut -d" " -f6`
				_ok=`validate_integer $_val $_min_val $_max_val`
				if [ $_ok != TRUE ]
				then					
					if [ "$_max_val" = "NA" ]
					then
						/bin/echo " ERROR - Invalid value for $_key. Value between $_min_val and 2147483647 inclusive."
					else
						/bin/echo " ERROR - Invalid value for $_key. Value between $_min_val and $_max_val inclusive."
					fi
				else
					/bin/echo " Setting $_key to $_val."
					setConfig diag.$MyName.$_key $_mode_val "$_val"
					_modified=TRUE
				fi
			else
				/bin/echo " Setting $_key to $_val."
				setConfig diag.$MyName.$_key $_mode_val "$_val"
				_modified=TRUE
			fi
		else
			/bin/echo Could not find PARAMDEF for $_key
		fi
	done
	_num_env=0
	config_list=`get_config_list`
	_env=""
}

##################################
# This function process_diagsetcycle() is for library use only.
# It processes the remaining command line arguments, and dispatches
# work to one of four processing routines (diagsetcycledefault,
# diagsetcycleshow, diagsetcycleparameters, diagsetcycleinteractive).
#
# Each of these processing routines can be called multiple times in
# the order specified in the command line except for the interactive
# processer. The interactive is only called if no other option is
# specified.
#
# If any of the processing routines modified the content of the
# config database during their operation, the config database is 
# committed to non-volitile storage.
##################################
process_diagsetcycle()
{
	_param_list=`get_param_list`
	_param_list_with_cr=`get_param_list_with_cr`

	_num_params=`/bin/echo $_param_list | \
				 /usr/bin/tr -s " " "_" | \
				 /usr/bin/tr -s "@" " " | \
				 /usr/bin/wc -w`
	export _num_params

#	echo "_num_params=$_num_params"
	# Cache the config data base
	config_list=`get_config_list`
#	echo "config_list:"
#   echo "$config_list"
	_modified=FALSE
	_interactive=TRUE
	_parameters=FALSE
	_num_show=0	
	_num_default=0	
#	echo "$# ..."
	if [ "$#" -ne 0 ]
	then
		_num_env=0
		shift
		_env=""

		
		if [ $_num_show -gt 1 ]
		then
			/bin/echo "Invalid entry for the keyword $_pre_par, re-enter the command"
			exit 0
		fi
		
		while [ "$#" -gt 0 ]
		do
	        #echo "$# ... $1"
			_par=`/bin/echo $1 | /usr/bin/sed "s/^-//g"`
			shift
			case "$_par" in 
			"default") if [ $_parameters = TRUE ]
				   then
					/bin/echo "Invalid entry for the keyword default, re-enter the command"
					exit 0
				   else
				   	_num_default=`/bin/expr $_num_default + 1`
				   fi;;
			"show")    if [ $_parameters = TRUE ]
				   then
					/bin/echo "Invalid entry for the keyword show, re-enter the command"
					exit 0
				   else
				   	_num_show=`/bin/expr $_num_show + 1`
				   fi;;
			*)  if [ $_num_show -ge 1 ]
			    then
				   /bin/echo "Invalid entry for the keyword show, re-enter the command"
				  exit 0
			    fi
			    if [ $_num_default -ge 1 ]
			    then
				   /bin/echo "Invalid entry for the keyword default, re-enter the command"
				  exit 0
			    fi
			    if [ $# -eq 0 ]
			    then
				    /bin/echo "There was no value for the keyword $_par."
				    exit 0
			    else
				    _val=`/bin/echo $* | /usr/bin/cut -d"-" -f1`
				    _env=`/bin/echo "$_env@$_par $_val"`
				    num_args=`/bin/echo $_val | /usr/bin/wc -w`
				    while [ $num_args -gt 0 ]
				    do
					    shift
					    num_args=`/bin/expr $num_args - 1`
				    done
				    _num_env=`/bin/expr $_num_env + 1`
				   _interactive=FALSE
				   _parameters=TRUE
			    fi;;
			esac
		done
		if [ $_num_show -ge 1 -a $_num_default -ge 1 ]
		then
			/bin/echo "Invalid entry for the keyword show and default, re-enter the command"
			exit 0
		fi
		if [ $_num_default -gt 1 ]
		then
			/bin/echo "Invalid entry for the keyword default, re-enter the command"
			exit 0
		fi
		if [ $_num_show -gt 1 ]
		then
			/bin/echo "Invalid entry for the keyword show, re-enter the command"
			exit 0
		fi
		if [ $_num_default -eq 1 ]
		then
			if [ $_parameters = TRUE ]
			then
				/bin/echo "Invalid entry for the keyword default, re-enter the command"
			else
				diagsetcycledefault
				_interactive=FALSE
		   	fi
		   	exit 0
		fi
		if [ $_num_show -eq 1 ]
		then
			if [ $_parameters = TRUE ]
			then
				/bin/echo "Invalid entry for the keyword show, re-enter the command"
			else
				diagsetcycleshow
				_interactive=FALSE
		   	fi
		   	exit 0
		fi		
		if [ $_interactive = TRUE ]
		then
			diagsetcycleinteractive
		fi
		if [ $_parameters = TRUE ]
		then
			diagsetcycleparameters
		fi
		if [ "$_modified" = "TRUE" ]
		then
			/bin/echo "Committing changes to configuration"
			updateConfig
		fi
	fi
	#echo "process_diagsetcycle() done"
	exit 0
}

####################################
# get_stats gets the environmental statistics (temperature and voltage) of the unit
####################################
get_stats()
{
    # archer: hardcode temp and volts
    #_cmd=`commandPath tempshow`
    #temp=`$_cmd | /usr/bin/tr -s "   " "  " | /usr/bin/grep -w $Slot | /usr/bin/cut -d" " -f4 | /usr/bin/xargs`
    #_cmd=`commandPath voltshow`
    #if [ $MultiBlade = TRUE ]
    #then
	#volts=`$_cmd | /usr/bin/tr -s " " " " | /usr/bin/grep Slot | /usr/bin/grep ": $Slot" | /usr/bin/cut -d" " -f5-7,9`
    #else
	#volts=`$_cmd | /usr/bin/tr -s " " " " | /usr/bin/grep Switch | /usr/bin/cut -d" " -f2-6`
    #fi
	temp=72
	volts=5
    echo "$volts $temp"
}

####################################
# PRIVATE STATUS AND SIGNAL HANDLING
#
# cleanup() function to process trapped signal received. 
# since the script handles two operations (diagsetcycle and burnin),
# the abort operation must be aware of which operation is active.
#
# For the diagsetcycle operation, only the exit with status is
# performed.
#
# For the burnin operation, any active child process is killed
# with the TERM signal, status, and messages are output, then the
# normal exit function is called
####################################
diagcommon_cleanup()
{
	if [ "$State" = "DIAGSETCYCLE" ]
	then
		exit $CumulativeStatus
	fi

	if [ "$LogFile" = "/var/log/switchburnin.1.log" ]
	then
		/usr/pkg/sbin/diagpost 1
		/usr/pkg/diagscripts/cmddir/diagmode "normal"		
	fi

	if [ $Child -ne 0 ]
	then
		/bin/kill -TERM $Child
		/bin/echo ""
		burninMessage "Exiting. Kill pid $Child"
	fi
	# set abort flag
	#
	State=ABORT
	burninMessage "Script has been ABORTED `/bin/date`"

	# have to bump RunNumber because cleanupOnExit decrements it 
	# once assumint completion is reason for stopping. On normal
	# completion RunNumber is one more than NumberOfCommands
	#
	# During abnormal completion, we need to emulate that behavior
	# before calling cleanupOnExit
	RunNumber=`/bin/expr $RunNumber + 1`
	export DIAG_PKG_PASS=$RunNumber

	cleanupOnExit
	exit $CumulativeStatus
}

####################################
# check_command_status() function monitors the exit status of the
# executed command. It waits for exec_diag return and process the
# return status. Both the RunStatus and CumulativeStatus are updated 
# based on failing results.
#
#	check_command_status $command_name $finish_time $ALL(TRUE/FALSE)
#
# Messages are generated to output the result of the command.
####################################
check_command_status()
{
	# wait for current child to finish and get return status
	#
        # export Child=$!
	# wait $Child
	# echo "check_command_status() child id $Child"
	#_testresult=$?
	# export Child=0
	_testresult=$_result1
	if [ $_testresult -eq 139 -o $_testresult -eq 237 ]
	then
		burninMessage "Command #$CmdNumber Run $DIAG_PKG_PASS Known issue ($_testresult) $_new_var"
		_testresult=16
	fi
	#
	# diagshow will only fail if a port has faulted.
	#
	# archer: add 
    _showresult=0
	# archer: we don't provide this function
	#_cmd=`commandPath exec_diag`
	# $_cmd diagshow --slot $Slot -silent 1 -use_bports 1 >> $LogFile
	# _showresult=$?
	# if [ $_showresult -eq 139 -o $_showresult -eq 237 ]
	# then
	# 	burninMessage "Command #$CmdNumber Run $DIAG_PKG_PASS Known issue ($_showresult) diagshow"
	#	_showresult=0
	# fi
    
	#  construct PASSED or FAILED msg from return value of command
	#  .  return value = 0 for PASSED
	#  .  return value != 0 for FAILED
	#
	# For all test status updating following table:
	#			        Normal test		"ALL" test
	#------------------------------------------------------------------
	#	Test P/F result		test return		"COMPLETE"
	#	Script cum status	test+show		show
	#	Blade LED		prev_cum+test+show	prev+show
	#
	# NOTE: that prev is handled in
	#  initialize_burnin_variables(). This reads the cumulative
	#  status from the non-volitile memory, and sets status and
	#  LED state based on that value. Therefore it does not need
	#  to be considered here.
	#
	# NOTE: REturn values of 237 or 139 idicate that there was a problem
	# with Linux actually executing the command. Since these commands never
	# were executed (diagshow or the actual command), their staus is ignored. 
	#
	if [ "$3" = "TRUE" -a $MultiBlade = TRUE ]
	then
		_stat=COMPLETE
		if [ $_showresult -ne 0 ]
		then
			CumulativeStatus=`/bin/expr $CumulativeStatus + 1`
			RunStatus=1
			# --setled only takes effect if the command fails.
			# net result is turn on the LED since test
			# will always fail
			_cmd=`commandPath exec_diag`
			if [ $MultiBlade = FALSE ]
			then
				# eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SLOW_BLINK > /dev/null 2>/dev/null
		        echo " *** check_command_status() exec_diag --slot $Slot --setled LED_CS_FAIL"
				eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_FAIL > /dev/null 2>/dev/null
			else
				eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SOLID_ON > /dev/null 2>/dev/null
			fi
			burninMessage "Found error in $1 during run $RunNumber showresult $_showresult"
			burninFailMessage "Found error in $1 during run $RunNumber showresult $_showresult"
		fi
	else
		case "$_testresult" in
		0)
			_stat=PASSED;;
		16)
			_stat=SKIPPED;;
		*)
			_stat=FAILED;;
		esac
		if [ $_showresult -ne 0 -o "$_stat" = "FAILED" ]
		then
			CumulativeStatus=`/bin/expr $CumulativeStatus + 1`
			# archer add for port state
			RunStatus=1
			# --setled only takes effect if the command fails.
			# net result is turn on the LED since test
			# will always fail
        	# echo "check_commad_statue(4)"
			_cmd=`commandPath exec_diag`
			if [ $MultiBlade = FALSE ]
			then
			    if [ -f /tmp/cmdlog ]
				then
                  cat /tmp/cmdlog >> "$LogFile.fail"
				  rm -f /tmp/cmdlog
				  if [ $MyName != "switchburnin" ]
	                          then
				    /usr/pkg/diagscripts/cmddir/diagtempshow 2>&1 >> "$LogFile.fail" 	
				  fi
				  
				  if [ $MyName = "switchess" ]
	                          then
				    /usr/pkg/diagscripts/cmddir/diagvoltshow -s 1 2>&1 >> "$LogFile.fail" 					  	   	   
	                          else
				    if [ $MyName = "switcherunin" ]
	                            then	                          
				    /usr/pkg/diagscripts/cmddir/diagvoltshow 2>&1 >> "$LogFile.fail" 					  	   	   
				    fi
				  fi
				fi
				# eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SLOW_BLINK  > /dev/null 2>/dev/null
		        #echo " *** check_command_status() exec_diag --slot $Slot --setled LED_CS_FAIL"
		        echo " *** check_command_status() exec_diag --setled LED_CS_FAIL"
				eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_FAIL  > /dev/null 2>/dev/null
			else
				eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SOLID_ON > /dev/null 2>/dev/null
			fi

			burninMessage "Found error in $1 during run $RunNumber showresult $_showresult testresult $_testresult"
			burninFailMessage "Found error in $1 during run $RunNumber showresult $_showresult testresult $_testresult"
	        burninFailMessage "Command #$CmdNumber Run $DIAG_PKG_PASS $_stat $1 `/bin/date` `get_stats`"
			burninFailMessage "setled LED_CS_FAIL"
			NumberOfRuns=$RunNumber
		fi
	fi
	burninMessage "Command #$CmdNumber Run $DIAG_PKG_PASS $_stat $1 `/bin/date` `get_stats`"
	_current_time=`/bin/date \+\%s`
	_duration=`/bin/expr $_current_time - $2`
	_minute=`/bin/expr $_duration / 60`
	_hour=`/bin/expr $_minute / 60`
	_sec=`/bin/expr $_duration % 60`
	_minute=`/bin/expr $_minute % 60`
	burninMessage "Command #$CmdNumber Run $DIAG_PKG_PASS Duration: $1 took $_hour hr $_minute min $_sec sec ($_hour:$_minute:$_sec)"
}

##################################
# NAME
#    initialize_burnin_variables - Initializes the variables used
#                                  to control the burnin process
#
# SYNOPSIS
#    initialize_burnin_variables
#
# DESCRIPTION
#    This function initialize_burnin_variables() is used by scripts
#    that need values from non-volitile memory. For burnin, these
#    are RunNumber, and State of the overall burnin, and the
#    CumulativeStatus of the run. These are gathered from the serial 
#    EEPROM on each blade.
#
#    The number of runs to execute are contained in the PARAMDEF stored in 
#    config database.
#
# OPERANDS
#    NONE
#
##################################
initialize_burnin_variables()
{
    # echo "initialize_burnin_variables()"
	export RunNumber=`getBladeParam $Slot RUN_NUMBER`
	# Set for the diag to use in logging
	export DIAG_PKG_PASS=$RunNumber
	export State=ACTIVE
	# echo " archer: RunNumber=$RunNumber"
	# echo " archer: DIAG_PKG_PASS=$DIAG_PKG_PASS"
	# echo " call getBladeParam()"
	CumulativeStatus=`getBladeParam $Slot CUM_STATUS`
	# Make sure LED's match test status after power cycle
	# exec_diag grabs all "--" arguments and executes them
	if [ $CumulativeStatus -ne 0 ]
	then
		# Failed already
		_cmd=`commandPath exec_diag`
		if [ $MultiBlade = FALSE ]
		then
			# eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SLOW_BLINK > /dev/null 2>/dev/null &
			#echo " *** exec_diag set_led --slot $Slot --setled LED_CS_FAIL"
			echo " *** exec_diag set_led --setled LED_CS_FAIL"
			eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_FAIL > /dev/null 2>/dev/null &
		else
			eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SOLID_ON > /dev/null 2>/dev/null &
		fi
		burninMessage "Stored status indicates cumulative fail."
	else
		# Passing so far
		_cmd=`commandPath exec_diag`
		if [ $MultiBlade = FALSE ]
		then
			# eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SOLID_ON > /dev/null 2>/dev/null &
			#echo " *** initialize_burnin() exec_diag --slot $Slot --setled LED_INIT_VARS"
			echo " *** initialize_burnin() exec_diag --setled LED_INIT_VARS"
			eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_INIT_VARS > /dev/null 2>/dev/null &
		else
			eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SLOW_BLINK > /dev/null 2>/dev/null &
		fi
	fi
	# format up the start time for the logging messages
	# archer:
	#_tmp=`/bin/cat /proc/dcomm`
	#_sec=`/bin/expr "$_tmp" : ".*time: \+\([0-9]\+\)"`
	#_msec=`/bin/expr "$_tmp" : ".*time: \+[0-9]\+:\([0-9]\+\)"`		  
	#if { [ -z $_sec ] || [ -z $_msec ] ; } ; then
	#	_sec=0
	#	_msec=0
	#fi
	#export DIAG_PKG_BEG="$_sec:$_msec"
	DIAG_PKG_BEG=`date`
	export DIAG_PKG_BEG

	# get the parameters for the script
	export RunStatus=`getBladeParam $Slot RUN_STATUS`
	export RunTime=`getBladeParam $Slot RUN_TIME`
	export TotalCmdNumber=`getBladeParam $Slot TOTAL_CMD_NUMBER`
	export CmdNumber=`getBladeParam $Slot CMD_NUMBER`
	export TotalThermal=`getBladeParam $Slot TEMP_CYCLE`
	export TotalVib=`getBladeParam $Slot VIB_CYCLE`
	export NumberOfRuns=`getConfig diag.$MyName.number_of_runs $INTEGER 1`
	export LogLength=`getConfig diag.$MyName.log_length $INTEGER 1048576`
	LogLength=`/bin/expr $LogLength \* 1024`
	LogLength=`/bin/expr $LogLength \* 1024`
	# echo " Log File Maximun Length is $LogLength"

	# archer add for port state
	getPortCumState

	if [ "$NumberOfRuns" = 1 ]
	then
	        ConfigSetCheck diag.$MyName.number_of_runs $INTEGER
		if [ $? != 0 ]
		then
		    setConfig diag.$MyName.number_of_runs $INTEGER 1
		fi
	fi
	Vib=`getConfig diag.$MyName.vib $INTEGER 0`
	if [ "$Vib" = 0 ]
	then
	        ConfigSetCheck diag.$MyName.vib $INTEGER
		if [ $? != 0 ]
		then
		    setConfig diag.$MyName.vib $INTEGER 0
		fi
	fi
	Thermal=`getConfig diag.$MyName.thermal $INTEGER 0`
	if [ "$Thermal" = 0 ]
	then
	        ConfigSetCheck diag.$MyName.thermal $INTEGER
		if [ $? != 0 ]
		then
		    setConfig diag.$MyName.thermal $INTEGER 0		  
		fi
	fi
}

calculatePortState()
{
  # echo "-----> calculate port state after a run cycle"
  port_id=1
  tmp_armmt_var=0
  tmp_mt_var=0
  tmp_alb_var=0
  run_state=0

  while [ $port_id -le 16 ]
  do
    # echo "calculatePortState($port_id)"
    tmp_amt_var=0
    tmp_mt_var=0
    tmp_alb_var=0
    run_state=0
    
	# amt test result
	armmt_file_name="/tmp/armmt.$port_id"
    if [ -f $armmt_file_name ]
	then
	  tmp_armmt_var=`/bin/cat $armmt_file_name`
      # cat $armmt_file_name | read tmp_armmt_var
	  run_state=1
	  # echo "***!!! port $port_id figmt result is $armmt_file_name"
	fi
	
	figmt_file_name="/tmp/figmt.$port_id"
    if [ -f $figmt_file_name ]
	then
	  tmp_mt_var=`/bin/cat $figmt_file_name`
      # cat $figmt_file_name | read tmp_mt_var
	  run_state=1
	  # echo "***!!! port $port_id figmt result is $tmp_mt_var"
	fi
	
    tmp_alb_var=`/usr/pkg/diagscripts/cmddir/getPortAlbState.sh`
	if [ $? -ne 0 ]
	then 
	  # echo "***!!! port $port_id figalb result is $tmp_alb_var"
	  run_state=1
	fi
	  
	case $port_id in
	  1) cur_state=$PCS01;;
	  2) cur_state=$PCS02;;
	  3) cur_state=$PCS03;;
	  4) cur_state=$PCS04;;
	  5) cur_state=$PCS05;;
	  6) cur_state=$PCS06;;
	  7) cur_state=$PCS07;;
	  8) cur_state=$PCS08;;
	  9) cur_state=$PCS09;;
	  10) cur_state=$PCS10;;
	  11) cur_state=$PCS11;;
	  12) cur_state=$PCS12;;
	  13) cur_state=$PCS13;;
	  14) cur_state=$PCS14;;
	  15) cur_state=$PCS15;;
	  16) cur_state=$PCS16;;
	esac

	# port test has run
	if [ $run_state -gt 0 ]
	then
	  
	  case $cur_state in
	  0)
	  cur_state=`/bin/expr $cur_state + $tmp_armmt_var`
	  cur_state=`/bin/expr $cur_state + $tmp_mt_var`
	  cur_state=`/bin/expr $cur_state + $tmp_alb_var`;;
	  1)
	  cur_state=`/bin/expr $cur_state + $tmp_mt_var`
	  cur_state=`/bin/expr $cur_state + $tmp_alb_var`;;
	  2)
	  cur_state=`/bin/expr $cur_state + $tmp_armmt_var`
	  cur_state=`/bin/expr $cur_state + $tmp_alb_var`;;
	  3)
	  cur_state=`/bin/expr $cur_state + $tmp_alb_var`;;
	  4)
	  cur_state=`/bin/expr $cur_state + $tmp_armmt_var`
	  cur_state=`/bin/expr $cur_state + $tmp_mt_var`;;
	  5)
	  cur_state=`/bin/expr $cur_state + $tmp_mt_var`;;
      6)
	  cur_state=`/bin/expr $cur_state + $tmp_armmt_var`;;
	  esac
	fi

	case $port_id in
	  1) PCS01=$cur_state;;
	  2) PCS02=$cur_state;;
	  3) PCS03=$cur_state;;
	  4) PCS04=$cur_state;;
	  5) PCS05=$cur_state;;
	  6) PCS06=$cur_state;;
	  7) PCS07=$cur_state;;
	  8) PCS08=$cur_state;;
	  9) PCS09=$cur_state;;
	  10) PCS10=$cur_state;;
	  11) PCS11=$cur_state;;
	  12) PCS12=$cur_state;;
	  13) PCS13=$cur_state;;
	  14) PCS14=$cur_state;;
	  15) PCS15=$cur_state;;
	  16) PCS16=$cur_state;;
	esac
    port_id=`/bin/expr $port_id + 1`
	
  done
  # printPortState

  # archer add for port state
  rm /tmp/figmt.* 2> /dev/null
  rm /tmp/figalb* 2> /dev/null
  rm /tmp/armmt.* 2> /dev/null

}

initPortState()
{
 # 0: ok, 1: amt err, 2:fig mt err, 4:fig alb err, 3: both fail 99: not run
 #   echo "********** initPortState()"
	export PCS01=99
	export PCS02=99
	export PCS03=99
	export PCS04=99
	export PCS05=99
	export PCS06=99
	export PCS07=99
	export PCS08=99
	export PCS09=99
	export PCS10=99
	export PCS11=99
	export PCS12=99
	export PCS13=99
	export PCS14=99
	export PCS15=99
	export PCS16=99
}

printPortState()
{
	echo "PCS01=$PCS01"
	echo "PCS02=$PCS02"
	echo "PCS03=$PCS03"
	echo "PCS04=$PCS04"
	echo "PCS05=$PCS05"
	echo "PCS06=$PCS06"
	echo "PCS07=$PCS07"
	echo "PCS08=$PCS08"
	echo "PCS09=$PCS09"
	echo "PCS10=$PCS10"
	echo "PCS11=$PCS11"
	echo "PCS12=$PCS12"
	echo "PCS13=$PCS13"
	echo "PCS14=$PCS14"
	echo "PCS15=$PCS15"
	echo "PCS16=$PCS16"

}

getPortCumState()
{
# export done at get_filename
#	export PCS01=`getPortState $Slot PCS01`
#	export PCS02=`getPortState $Slot PCS02`
#	export PCS03=`getPortState $Slot PCS03`
#	export PCS04=`getPortState $Slot PCS04`
#	export PCS05=`getPortState $Slot PCS05`
#	export PCS06=`getPortState $Slot PCS06`
#	export PCS07=`getPortState $Slot PCS07`
#	export PCS08=`getPortState $Slot PCS08`
#	export PCS09=`getPortState $Slot PCS09`
#	export PCS10=`getPortState $Slot PCS10`
#	export PCS11=`getPortState $Slot PCS11`
#	export PCS12=`getPortState $Slot PCS12`
#	export PCS13=`getPortState $Slot PCS13`
#	export PCS14=`getPortState $Slot PCS14`
#	export PCS15=`getPortState $Slot PCS15`
#	export PCS16=`getPortState $Slot PCS16`
 
 if [ -f /usr/pkg/diagscripts/share/portState.$Slot ]
 then
   PCS01=`getPortState $Slot PCS01`
   PCS02=`getPortState $Slot PCS02`
   PCS03=`getPortState $Slot PCS03`
   PCS04=`getPortState $Slot PCS04`
   PCS05=`getPortState $Slot PCS05`
   PCS06=`getPortState $Slot PCS06`
   PCS07=`getPortState $Slot PCS07`
   PCS08=`getPortState $Slot PCS08`
   PCS09=`getPortState $Slot PCS09`
   PCS10=`getPortState $Slot PCS10`
   PCS11=`getPortState $Slot PCS11`
   PCS12=`getPortState $Slot PCS12`
   PCS13=`getPortState $Slot PCS13`
   PCS14=`getPortState $Slot PCS14`
   PCS15=`getPortState $Slot PCS15`
   PCS16=`getPortState $Slot PCS16`
 fi
}

##################################
# NAME
#    get_filename - Get the name of the current script
#
# SYNOPSIS
#    get_filename
#
# DESCRIPTION
#    This command reads the shell arguments and extract the name 
#    of the command referenced by the user. The preceding 
#    directories are stripped as are the trailing extentions.
#
#    The burnin log files are created at the same time. They are:
#    LogFile, and UserFile
#
# OPERANDS
#    NONE
#
##################################
get_filename()
{
    # echo "************** get_filename()"
	# Initialize incase of trap
	export StartTime=`/bin/date \+\%s`
	export Child=0
	RunNumber=0
	TotalCmdNumber=0
	TotalThermal=0
	TotalVib=0
	CmdNumber=0

	# setup some default values
	export CumulativeStatus=0
	export Slot=$_def_slot
	export DIAG_POST=1
	export DCOMM_USR_FAILLIM=16

    # archer: comment off 1 line
	# setdbg DIAG 1
	# archer add for port state
	initPortState

	# get the main three: home, switch, and slot
	if [ ! -z "$FABOS_SLOTNO" ]
	then
		export Slot=$FABOS_SLOTNO
	else
		export FABOS_SLOTNO=$_def_slot
		export Slot=$FABOS_SLOTNO
	fi

	if [ -z "$FABOSHOME" ]
	then
		export FABOSHOME=/usr/pkg/diagscripts
	fi

	if [ -z "$FABOS_SWITCHNO" ]
	then
		export FABOS_SWITCHNO=0
	fi

	export MultiBlade=`isMultiBlade`
	export Product=`getSWBD`
	if [ $MultiBlade = TRUE ]
	then
		slot_message=" $Slot"
	else
		slot_message=""
	fi
	# save my PID
	/bin/echo "$$ ACTIVE" > /tmp/burnin_PID.$FABOS_SWITCHNO.$Slot

	# setup the file names to use
	_tmp_dir=`getConfig diag.mode.burnin.logpath $STRING "/var/log"`
	if [ ! -d $_tmp_dir ]
	then
		/bin/echo "Could not find diag.mode.burnin.logpath $_tmp_dir using /var/log"
		_tmp_dir="/var/log"
	fi
	_log_path=`getConfig diag.$MyName.LogFilePath $STRING "$_tmp_dir"`
	if [ ! -d $_log_path ]
	then
		/bin/echo "Could not find diag.$MyName.LogFilePath $_log_path using $_tmp_dir"
		_log_path=$_tmp_dir
	fi
	export LogCmd=`commandPath logdata`
	
	NamePrefix=$MyName
	if [ $MyName = "switchess" ]
	then
	   snlog=`/usr/pkg/diagscripts/cmddir/diagboardsnshow`
	   snret=$?
	   if [ $snret = "0" ]
	   then
	     SerNum=`/bin/echo $snlog | /usr/bin/cut -d" " -f5`	
	     NamePrefix=$SerNum
	   fi	   
	else
	   if [ $MyName = "switchrunin" ]
	   then	   
	      snlog=`/usr/pkg/diagscripts/cmddir/diagchassissnshow`
	      snret=$?
	      if [ $snret = "0" ]
	      then
	     	SerNum=`/bin/echo $snlog | /usr/bin/cut -d" " -f5`	
	     	NamePrefix=$SerNum
	      fi	   	   	   
	   fi
	fi	
	if [ "$NamePrefix" = "" ]
	then
	   NamePrefix=$MyName
	fi
	export LogFile=$_log_path/$NamePrefix.$Slot.log	
	burninMessage "Sending logs to $LogFile"
	# walk to path to ensure path is available
	export UserFile="$MyName.$Slot.usr"
}

##################################
# NAME
#    get_command_list - Get the output of the create_command_file
#		        function to stdout
#
# SYNOPSIS
#    get_command_list
#
# DESCRIPTION
#    This command executes the create_command_file function and places
#    a "@" seperator after every line that is a command. Any line that
#    is not a command is eliminated from the output by the "isCommand"
#    filter.
#
#    No need to filter for comment lines or empty lines. The function 
#    isACommand will do that for us.
#
# OPERANDS
#    NONE
#
##################################
get_command_list()
{
	create_command_file | while read _line
	do
		if [ `isACommand "$_line"` = "command" ]
		then
			/bin/echo $_line@

		fi
	done
}

##################################
# NAME
#    get_config_list - Get the output of the configShow diag entries
#		       to stdout.
#
# SYNOPSIS
#    get_config_list
#
# DESCRIPTION
#    This command executes the configShow function and places
#    a "@" seperator after every input line that belongs to the 
#    calling script. Any input line that is not related to the calling
#    script is eliminated from the output by the "/usr/bin/grep diag.$MyName"
#    filter.
#
# OPERANDS
#    NONE
#
##################################
get_config_list()
{
	_cmd=`commandPath configShow`
	$_cmd  2>/dev/null | /usr/bin/grep diag.$MyName | while read _line
	do
		/bin/echo $_line@
	done
}

##################################
# NAME
#    get_config_entry - Get the value of a "configVariable:value" pair
#		        from the output generated by get_config_list.
#
# SYNOPSIS
#    get_config_entry
#
# DESCRIPTION
#    This command searches the output of config_list until a match on
#    the traget is found. The sed outputs the string starting from the
#    match of $target until the "@" seperator. The "cut" on ":" delimiter
#    trims off $target and the ":". The "cut" on "@" delimiter
#    removes the "@" sight leaving the value of the config variable
#    named $target.
#
# OPERANDS
#    $1 = target to match in the string
#    config_list = variable containing the string to search
#
##################################
get_config_entry()
{
	target=$1
#	echo $config_list >> tmp.log
	if [ ! -z "`/bin/echo $config_list | /usr/bin/grep $target`" ]
	then
#		tmp_list=`/bin/echo $config_list | \
#		     /usr/bin/sed -e "s/^.*\(${target}:[[:print:]]*\)/\1/g"`
#		tmp_value=`/bin/echo $config_list | \
#		     /usr/bin/sed -e "s/^.*\(${target}:[[:print:]]\)/\1/g" |\
#		     /usr/bin/cut -d":" -f2 | \
#		     /usr/bin/cut -d"@" -f1`
#
#       echo "$target=$tmp_value" >> tmp.log
#		echo "$tmp_list" >> tmp.log
		 /bin/echo $config_list | \
		     /usr/bin/sed -e "s/^.*\(${target}:[[:print:]]\)/\1/g" |\
		     /usr/bin/cut -d":" -f2 | \
		     /usr/bin/cut -d"@" -f1
	fi
}

##################################
# NAME
#    get_param_list - Get the output of the create_param_file
#		        function to stdout
#
# SYNOPSIS
#    get_param_list
#
# DESCRIPTION
#    This command executes the create_param_file function and places
#    a "@" seperator after every line that is a paramdef. Any line that
#    is not a param is eliminated from the output by the "PARAMDEF"
#    filter.
#
#    Added filter for lines that are comments. They could be commented
#    out PARAMDEFs.
#
# OPERANDS
#    NONE
#
##################################
get_param_list()
{
	create_param_file | /usr/bin/grep -v "^#" | while read _line
	do
		if [ ! -z "`/bin/echo $_line | /usr/bin/grep 'PARAMDEF'`" ]
		then
			/bin/echo $_line@

		fi
	done
}

get_param_list_with_cr()
{
	create_param_file | /usr/bin/grep -v "^#" | while read _line
	do
		if [ ! -z "`/bin/echo $_line | /usr/bin/grep 'PARAMDEF'`" ]
		then
			/bin/echo $_line 
		fi
	done
}

get_param_line()
{
  _num_line=$1
  _num_count=1
  # !!! archer: must have "", or the cr will be ignored
  echo "$_param_list_with_cr" | while read _line
  do
    if [ $_num_count -eq $_num_line ]
    then
      echo $_line
      break
    fi
    _num_count=`/bin/expr $_num_count + 1`
  done
}

##################################
# NAME
#    get_match_list - Get a list of the lines that contain the string
#		      $2 to stdout
#
# SYNOPSIS
#    get_match_list <file> <match_string>
#
# DESCRIPTION
#    This searches file named $1 for string $2 and places a @seperated
#    list of the lines that matches were found.
#
#    The output is a single line with "@" seperated
#    match strings.
#
# OPERANDS
#    NONE
#
##################################
get_match_list()
{
	_fil=$1
	shift
	/bin/cat "$_fil" | /usr/bin/grep -n $* | while read _line
	do
		/bin/echo $_line@
	done
}

##################################
# NAME
#    get_error_from_file - Get the error entries in a log file
#
# SYNOPSIS
#    get_error_from_file <file>
#
# DESCRIPTION
#    This searches file named $1 for string ERROR and places a @seperated
#    list of the lines that matches were found.
#
# OPERANDS
#    NONE
#
##################################
get_error_from_file()
{
	_list=`get_match_list $1 "-e ERROR -e BLOOM -e BLADE"`
	_count=1
	_lin=`/bin/echo $_list | /usr/bin/cut -d"@" -f$_count`
	while [ "$_lin" != "" ]
	do
		# get the line number of the ERROR, BLOOM or BLADE
		num1=`/bin/echo $_lin | /usr/bin/cut -d":" -f1`
		# get the actual line
		newlin=`/bin/cat $1 | /usr/bin/grep -n "^" | /usr/bin/grep -e "^${num1}:" | /usr/bin/cut -d":" -f2-`
		if [ "`/bin/echo $newlin | /usr/bin/grep -e BLOOM -e BLADE`" != "" ]
		then
			# BLOOM log processing
			/bin/echo $newlin
		else
			done=`/bin/echo $newlin | /usr/bin/grep "Err#"`
			while [ "$done" = "" ]
			do
				/bin/cat $1 | /usr/bin/grep -n "^" | \
				/usr/bin/grep -e "^${num1}:" | /usr/bin/cut -d":" -f2-
				num1=`/bin/expr $num1 + 1`
				newlin=`/bin/cat $1 | /usr/bin/grep -n "^" | /usr/bin/grep -e "^${num1}:" | /usr/bin/cut -d":" -f2-`
				done=`/bin/echo $newlin | /usr/bin/grep "Err#"`
			done
			/bin/cat $1 | /usr/bin/grep -n "^" | \
			/usr/bin/grep -e "^${num1}:" | /usr/bin/cut -d":" -f2-
		fi
		_count=`/bin/expr $_count + 1`
		_lin=`/bin/echo $_list | /usr/bin/cut -d"@" -f$_count`
	done
}

##################################
# NAME
#    get_driver_errors - Searches the burninerr log for bloom driver
#			 or blade driver errors during the current 
#			 burnin run.
#
# SYNOPSIS
#    get_driver_errors
#
# DESCRIPTION
#    This function get_driver_errors() assumes that the entries
#    in the burninerrshow output are in cronological order.
#    It also assumes that a burnin cycle is active, and that it must
#    have a start message before this function has been called.
#
#    The entire burnin error log is sampled to determine if there are
#    any BLADE/BLOOM entries at all. If some are detected, then the
#    last burnin start message is located, and its line number in the
#    output is saved. If a start mesage is not found, then it is
#    assumed that the errors are valid, and a message is output, and
#    fail status returned.
#
#    Once the position of the last start message is located, then the
#    position of each BLOOM error is compared to that of the start. If
#    the error appears after the start, then the error is considered
#    within this run, and error messages and status are sent. The same
#    process is performed for the BLADE errors.
#
# RESULT
#    The result of the testing is found by the existance of the file
#    /var/log/driver_stat_$Slot. If the file exists, then an error was
#    found. If it does not exist, then no error was found.
#
#    It is the callers responsibility to remove the file after testing
#    for the result. This function will remove it prior to the evaluation
#    to ensure the accuracy of the testing.
#
# OPERANDS
#    $1 after_inc - inicates the function was called after the
#	RunNumber was incremented at the end of the run.
#
##################################
get_driver_errors()
{
	if [ "$1" = "after_inc" ]
	then
		_run=`/bin/expr $RunNumber - 1`
	fi
	#_cmd=`commandPath burninerrshow`
	/bin/rm -f  /tmp/driver_stat_$Slot
	/usr/pkg/sbin/burninerrshow $Slot > /tmp/$$.tmp
	if [ "`/usr/bin/grep -e BLOOM -e BLADE /tmp/$$.tmp | /usr/bin/grep -v Warn`" != "" ]
	then
		_last_start=`cat /tmp/$$.tmp | \
				/usr/bin/tr -s "\000 " " " | \
				/usr/bin/grep -n Starting | \
				/usr/bin/tail -n1 | \
				/usr/bin/cut -d":" -f1`
		if [ "$_last_start" != "" ]
		then
			cat /tmp/$$.tmp | \
			/usr/bin/tr -s "\000 " " " | \
			/usr/bin/grep -n BLOOM | \
			/usr/bin/grep -v Warn |\
			/usr/bin/cut -d":" -f1 | \
			while read bloom_line
			do
				if [ ! -z "$bloom_line" ]
				then
					if [ $bloom_line -gt $_last_start ]
					then
						touch /tmp/driver_stat_$Slot
						burninMessage "BLOOM errors detected during run $_run"
						break;
					fi
				fi
			done
			if [ ! -f /tmp/driver_stat_$Slot ]
			then
				cat /tmp/$$.tmp | \
				/usr/bin/tr -s "\000 " " " | \
				/usr/bin/grep -n BLADE | \
				/usr/bin/grep -v Warn |\
				/usr/bin/cut -d":" -f1 | \
				while read blade_line
				do
					if [ ! -z "$blade_line" ]
					then
						if [ $blade_line -gt $_last_start ]
						then
							touch /tmp/driver_stat_$Slot
							burninMessage "BLADE errors detected during run $_run"
							break;
						fi
					fi
				done
			fi
		else
			touch /tmp/driver_stat_$Slot
			/burninMessage "BLOOM/BLADE errors detected during run $_run, but no Start message"
		fi
	fi
	/bin/rm -f  /tmp/$$.tmp
}

##################################
# NAME
#    get_any_errors - Searches the burninerr log for any errors during
#		      the current burnin run.
#
# SYNOPSIS
#    get_any_errors
#
# DESCRIPTION
#    This function get_any_errors() assumes that the entries
#    in the burninerrshow output are in cronological order.
#    It also assumes that a burnin cycle is active, and that it must
#    have a start message before this function has been called.
#
#    The entire burnin error log is sampled to determine if there are
#    any error entries at all. If some are detected, then the
#    last burnin start message is located, and its line number in the
#    output is saved. If a start mesage is not found, then it is
#    assumed that the errors are valid, and a message is output, and
#    fail status returned.
#
#    Once the position of the last start message is located, then the
#    position of each error is compared to that of the start. If
#    the error appears after the start, then the error is considered
#    within this run, and error messages and status are sent.
#
# RESULT
#    The result of the testing is found by the existance of the file
#    /var/log/error_stat_$Slot. If the file exists, then an error was
#    found. If it does not exist, then no error was found.
#
#    It is the callers responsibility to remove the file after testing
#    for the result. This function will remove it prior to the evaluation
#    to ensure the accuracy of the testing.
#
# OPERANDS
#    NONE
#
##################################
get_any_errors()
{
	#_cmd=`commandPath burninerrshow`
	/bin/rm -f  /tmp/error_stat_$Slot
	/usr/pkg/sbin/burninerrshow $Slot > /tmp/$$.tmp
	if [ "`/usr/bin/grep -e "^Switch: " /tmp/$$.tmp | /usr/bin/grep -v Warn`" != "" ]
	then
		_last_start=`cat /tmp/$$.tmp | \
				/usr/bin/tr -s "\000 " " " | \
				/usr/bin/grep -n Starting | \
				/usr/bin/tail -n1 | \
				/usr/bin/cut -d":" -f1`
		if [ "$_last_start" != "" ]
		then
			cat /tmp/$$.tmp | \
			/usr/bin/tr -s "\000 " " " | \
			/usr/bin/grep -n "^Switch:" | \
			/usr/bin/grep -v Warn |\
			/usr/bin/grep -v "WARNING: High temp" |\
			/usr/bin/cut -d":" -f1 | \
			while read error_line
			do
				if [ ! -z "$error_line" ]
				then
					if [ $error_line -gt $_last_start ]
					then
						touch /tmp/error_stat_$Slot
						burninMessage "Errors detected during run $_run"
						break;
					fi
				fi
			done
		else
			touch /tmp/error_stat_$Slot
			burninMessage "Errors detected during run $_run, but no Start message"
		fi
	fi
	/bin/rm -f  /tmp/$$.tmp
}

##################################
# NAME
#    setup_environment - Sets up the working environment of script
#
# SYNOPSIS
#    setup_environment
#
# DESCRIPTION
#    This function setup_environment() initialized the shell
#    environment with the necessary environment variables
#    to function on a blade within the fabos environment.
#    If any of the mandatory variables are not available,
#    the script will exit with a value of 3.
#
#    The action of modifying, or ensuring a value for each 
#    variable is called based on the input parameters to 
#    the script (diagsetcycle). If diagsetcycle is specified, 
#    then the script prompts the user and exits successfully.
#
#    If diagsetcycle is not specified, then the paramdef 
#    files are processed nto the config database, and exported 
#    into the shell environment.
#
# OPERANDS
#    NONE
#
##################################
setup_environment()
{
	#
	# Begin processing the PARAMETERS
	#
	import_burnin_variables

	#
	# Begin processing the COMMAND file content
	#

	CommandList=`get_command_list`
	export CommandList
	
	NumberOfCommands=`/bin/echo $CommandList | \
				 /usr/bin/tr -s " " "_" | \
				 /usr/bin/tr -s "@" " " | \
				 /usr/bin/wc -w`
	export NumberOfCommands
}
##################################
# NAME
#    truncate_log - Truncate log to prevent file system overflow
#
# SYNOPSIS
#    truncate_log
#
# DESCRIPTION
#    This function truncate_log() determine if the log file is greater
#    than $LogLength characters in size, and truncate  it to 3/4 the
#    number of lines after putting all errors in the file at the
#    top of the file.
#
#    NOTE: that if the LogLength is too small and/or the number of
#    errors is great, that the resulting file can be larger than LogLength.
#
# check log file length, trim the log file if necessary
# Trim log file if greater than LogLength (300000 default) characters
# 300000 X 8 blades = 2.4 meg * 2 = 4.8 Meg (*2 max growth per test)
# tmp logs 3/4 4.8 meg = 3.6 Meg + 4.8 Meg = 7.4 Meg of log files
# 8 Meg is about all the space we have to operate in.
#
# OPERANDS
#    NONE
#
##################################
truncate_log()
{
  logfilename=$LogFile
  if [ "$1" = "FAIL_LOG" ]
  then
    logfilename="$LogFile.fail"	    
  fi
    
  # echo "truncate $logfilename"

  if [ -f "$logfilename" ]
  then
	if [ $LogLength -ne 0 ]
	then
		_length_of_log=`/usr/bin/wc $logfilename | \
			/usr/bin/tr -s " " " " | \
			/usr/bin/cut -d" " -f4`
		if [ $_length_of_log -gt $LogLength ]
		then
			# get all the errors from the current file
			get_error_from_file $logfilename > $logfilename.err
			# trim the file by 3/4 lines
			_length_of_log=`/usr/bin/wc -l $logfilename | \
				/usr/bin/tr -s " " " " | \
				/usr/bin/cut -d" " -f2`
			_new_length=`/bin/expr $_length_of_log / 4`
			_new_length=`/bin/expr $_new_length \* 3`
			/usr/bin/tail -n $_new_length $logfilename > $logfilename.tmp
			/bin/cat $logfilename.err $logfilename.tmp > $logfilename
			/bin/rm -f $logfilename.tmp $logfilename.err
			burninMessage "Trimmed log from $_length_of_log to $_new_length"
			/bin/sync
		fi
	fi
  fi
}
##################################
#PUBLIC FUNCTIONS
##################################
##################################
# This function burninMessage() is intended for
# internal use only. It formats the output messages during burnin to
# be blade product sensative.
#
# It gets the message to output as the input parameters, and prepends
# slot information if appropriate.
# $* = message to output
##################################
burninMessage()
{
	/bin/echo "$slot_message $MyName: $*"
	$LogCmd $LogFile "$slot_message $MyName: $*"
}
##################################
# This function burninMessage() is intended for
# internal use only. It formats the output messages during burnin to
# be blade product sensative.
#
# It gets the message to output as the input parameters, and prepends
# slot information if appropriate.
# $* = message to output
##################################
burninFailMessage()
{
    FailLogFile="$LogFile.fail"
	# /bin/echo "$slot_message $MyName: $*"
	$LogCmd $FailLogFile "$slot_message $MyName: $*"
}
##################################
# NAME
#    getSWBD - Output the software board ID
#
# SYNOPSIS
#    getSWBD
#
# DESCRIPTION
#    This function parses the output of the sin command to extract the
#    SWBD value for this platform.
#
# OPERANDS
#    NONE
##################################
# archer changed -->
#getSWBD()
#{
#	_abc=`/sbin/sin | \
#		  /usr/bin/grep Platform | \
#		  /usr/bin/cut -d" " -f2 | \
#		  /usr/bin/cut -d"," -f1`
#	echo $_abc
#}
getSWBD()
{
    echo "1234"
}
# archer changed <--
##################################
# NAME
#    isMultiBlade - Output TRUE if product has multiple blades
#
# SYNOPSIS
#    isMultiBlade
#
# DESCRIPTION
#    This function parses the output of the sin command to extract the
#    SWBD value for this platform, then it uses that information to
#    determine a TRUE/FALSE answer.
#
# OPERANDS
#    NONE
##################################
isMultiBlade()
{
# archer changed -->
#	_abc=`/sbin/sin | \
#		  /usr/bin/grep Platform | \
#		  /usr/bin/cut -d" " -f2 | \
#		  /usr/bin/cut -d"," -f1`
#	case $_abc in 
#	"SWBD10" ) /bin/echo "TRUE";;
#	* ) /bin/echo "FALSE";;
#	esac
# archer changed <--
    echo "FALSE"
}
##################################
# NAME
#    getAvailSlots - Output a space seperated list of the slots on this switch
#
# SYNOPSIS
#    getAvailSlots
#
# DESCRIPTION
#    This function parses the output of the diagshow command to extract the
#    list of slots available in this switch.
#
# OPERANDS
#    NONE
##################################
getAvailSlots()
{
	_cmd=`commandPath exec_diag`
	_abc=`$_cmd diagshow | \
		/usr/bin/grep Slot | \
		/usr/bin/cut -d " " -f2 | \
		/usr/bin/xargs /bin/echo`
	echo "$_abc"
}
##################################
# NAME
#    isValidSlot - Output TRUE if valid slot number otherwise FALSE
#
# SYNOPSIS
#    isValidSlot
#
# DESCRIPTION
#    This function validate the input user slot number if
#    it is a valid or not by comparing with the result of getAvailSlots.
#    Then it will return TRUE/FALSE answer
# OPERANDS
#     $1 = user input slot number for validation
##################################
isValidSlot()
{

slot="$1"
list=`getAvailSlots`
if [ -z $1 ] ; then
   /bin/echo "FALSE"
else
     if [ "`/bin/echo $list | /usr/bin/grep -w $slot`" = "" ] ; then
	/bin/echo "FALSE"
     else
	/bin/echo "TRUE"
     fi
fi

}
##################################
# NAME
#    checkBurninState - Determines if burnin can continue
#
# SYNOPSIS
#    checkBurninState
#
# DESCRIPTION
#    This function checkBurninState() handles getting the script
#    variables initialized, and handles the diagsetcycle functionlity.
#
#    If the scripts is not in diagsetcycle mode, then it
#    determines if it is OK to start a burnin run. 
#    If the burnin State is COMPLETE, then it is not safe to start 
#    burnin. This differentiates a real start from a power cycle of 
#    the same burnin run.
#
# OPERANDS
#    NONE
##################################
checkBurninState()
{
	# get my name
	export debug_on=0
	_num_sub=`/bin/echo $0 | /usr/bin/tr "\057" " " | /usr/bin/wc -w`
	_num_sub=`/bin/expr $_num_sub + 1`

#	echo "_num_sub=$_num_sub"
	export MyName=`/bin/echo $0 | /usr/bin/tr "\057" "@" | \
			  /usr/bin/cut -d"@" -f$_num_sub | \
			  /usr/bin/cut -d"." -f1`
#	echo "MyName = $MyName"
	if [ -z "$MyName" ]
        then
		_num_sub=`/bin/echo $0 | /usr/bin/tr "\057" " " | /usr/bin/wc -w`
		export MyName=`/bin/echo $0 | /usr/bin/tr "\057" "@" | \
				  /usr/bin/cut -d"@" -f$_num_sub | \
				  /usr/bin/cut -d"." -f1`
	fi
	export FileName=`/bin/echo $0 | /usr/bin/tr "\057" "@" | \
			    /usr/bin/cut -d"@" -f$_num_sub`
#	echo "FileName=$FileName"


	# if only diagsetcycle, then process the environment
	if [ "$1" = "diagsetcycle" ]
	then
		export State=DIAGSETCYCLE
		process_diagsetcycle $*
		exit 0
	fi

    # echo "**************************************************"
	# echo "slot = $Slot"
    # echo "**************************************************"

    # archer add comments
    # the get_filename export all the global variables including CumulativeStatus, PCS01....
	get_filename
	_stored_state=`getBladeParam $Slot STATE`
	CumulativeStatus=`getBladeParam $Slot CUM_STATUS`
	getPortCumState
	
	if [ "$_stored_state" = "COMPLETED" -o "$_stored_state" = "ABORT"  ] 
	then
		/bin/echo "$$ COMPLETE" > /tmp/burnin_PID.$FABOS_SWITCHNO.$Slot
		/bin/echo "The last $MyName run ran to completion."
		/bin/echo "Please run diagSetBurnin if you wish to begin a new run."
		/bin/echo "    or run diagStopBurnin if you wish to exit burnin mode."
		_cmd=`commandPath exec_diag`
		if [ $CumulativeStatus = 0 ]
		then
			# We have passed
			if [ $MultiBlade = FALSE ]
			then
		        #echo " *** checkBurninState() exec_diag --slot $Slot --setled LED_CS_PASS"
		        echo " *** checkBurninState() exec_diag --setled LED_CS_PASS"
				eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_FAST_BLINK > /dev/null 2>/dev/null &
				/usr/pkg/diagscripts/cmddir/setportled 0xff a g 1 0 &
				_cmd=`commandPath switchbeacon`
				$_cmd 1
			else
				eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_DEFAULT > /dev/null 2>/dev/null &
				_cmd=`commandPath bladebeacon`
				$_cmd $Slot 1
			fi
		else
			# We have failed
			if [ $MultiBlade = FALSE ]
			then
		        #echo " *** checkBurninState() eval exec_diag set_led --slot $Slot --setled LED_CS_FAIL"
		        echo " *** checkBurninState() eval exec_diag set_led --setled LED_CS_FAIL"
				# eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SLOW_BLINK > /dev/null 2>/dev/null
				eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_FAIL > /dev/null 2>/dev/null
				/usr/pkg/diagscripts/cmddir/setportled 0xff a y 1 0 &
				_cmd=`commandPath switchbeacon`
				$_cmd 1
			else
				eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SOLID_ON > /dev/null 2>/dev/null
				_cmd=`commandPath bladebeacon`
				$_cmd $Slot 1
			fi
		fi
		exit $CumulativeStatus
	else
	    # echo "*****************************************************************************"
		_script_name=`getBladeParam $Slot SCRIPT_NAME`
		_num_sub=`/bin/echo $_script_name | /usr/bin/tr "\057" " " | /usr/bin/wc -w`
		_num_sub=`/bin/expr $_num_sub + 1`
		_script_name=`/bin/echo $_script_name | /usr/bin/tr "\057" "@" | \
					/usr/bin/cut -d"@" -f$_num_sub`
					
		if [ -z "$_script_name" ]
		then
			_num_sub=`/bin/echo $0 | /usr/bin/tr "\057" " " | /usr/bin/wc -w`
				_script_name=`/bin/echo $_script_name | /usr/bin/tr "\057" "@" | \
				  /usr/bin/cut -d"@" -f$_num_sub`
		fi
		if [ "$_script_name" != "$FileName" ]
		then
			/bin/echo "$$ COMPLETE" > /tmp/burnin_PID.$FABOS_SWITCHNO.$Slot
			burninMessage "Found wrong script specified, Please run diagSetBurnin"
			burninMessage "I am: $FileName, database is: $_script_name"
			_cmd=`commandPath exec_diag`
			if [ $CumulativeStatus = 0 ]
			then
				# We have passed
				if [ $MultiBlade = FALSE ]
				then
		            #echo " *** checkBurninState() exec_diag --slot $Slot --setled LED_CS_PASS"
		            echo " *** checkBurninState() exec_diag --setled LED_CS_PASS"
					# eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_FAST_BLINK > /dev/null 2>/dev/null &
					eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_PASS > /dev/null 2>/dev/null &
					_cmd=`commandPath switchbeacon`
					$_cmd 1
				else
					eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_DEFAULT > /dev/null 2>/dev/null &
					_cmd=`commandPath bladebeacon`
					$_cmd $Slot 1
				fi
			else
				# We have failed
				if [ $MultiBlade = FALSE ]
				then
					# eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SLOW_BLINK > /dev/null 2>/dev/null
		            #echo " *** checkBurninState() exec_diag set_led --slot $Slot --setled LED_CS_FAIL"
		            echo " *** checkBurninState() exec_diag set_led --setled LED_CS_FAIL"
					# eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_FAIL > /dev/null 2>/dev/null
					eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_FAIL /dev/null 2>/dev/null
					_cmd=`commandPath switchbeacon`
					$_cmd 1
				else
					eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SOLID_ON > /dev/null 2>/dev/null
					_cmd=`commandPath bladebeacon`
					$_cmd $Slot 1
				fi
			fi
			exit $CumulativeStatus
		fi

		setup_environment $*

		# Save the fact that we went live
		export State=ACTIVE

		#
		# Get the cp slot, and post to CP log
		#
		           # archer: _cmd=`commandPath getCPSlot`
		_cp_slot=0 # archer: _cp_slot=`$_cmd | /usr/bin/cut -d" " -f3`
		_cmd=`commandPath exec_diag`

        #archer:
		#_first_slot=`$_cmd diagshow | \
		#		/usr/bin/grep Slot | \
		#		/usr/bin/cut -d " " -f2 | \
		#		/usr/bin/xargs /bin/echo | \
		#		/usr/bin/cut -d " " -f1`
		_first_slot=0

	    if [ "$FABOS_SWITCHNO" -ne 0 ]
		then
		    echo "export FABOS_SWITCHNO variable"
		    export FABOS_SWITCHNO=0
		    _sw0_first_slot=`$_cmd diagshow | \
				/usr/bin/grep Slot | \
				/usr/bin/cut -d " " -f2 | \
				/usr/bin/xargs /bin/echo | \
				/usr/bin/cut -d " " -f1`
		    export FABOS_SWITCHNO=1

                    if [ ! -z "$_sw0_first_slot" ]
		    then
			 _first_slot=$_sw0_first_slot
		    fi
		fi
        
		_date=`/bin/date`
		# archer: _cmd=`commandPath version`
		_version=1 # archer: _version=`$_cmd | /usr/bin/grep Fabric | /usr/bin/tr -s " " " " | /usr/bin/cut -d " " -f3`
		if [ $MultiBlade = TRUE ]
		then
			if [ $_first_slot -eq $Slot ]
			then
				_message=" $Slot CP $_cp_slot Starting $MyName run $RunNumber $_version $_date"
				# Remove double spaces in the message for the forceError command
				_message=`/bin/echo "$_message" | /usr/bin/tr -s " " " "`
				_cmd=`commandPath exec_diag`
				$_cmd forceError --slot $_cp_slot -severity 4 -message '"'"$_message"'"'
			fi
	    fi

		# get the run and command numbers
		initialize_burnin_variables	
		#echo " archer: Current _stored_state=$_stored_state"
		if [ "$_stored_state" = "INITIALIZED" ]
		then
			burninMessage "Run diagClearError"
			_cmd=`commandPath exec_diag`
			$_cmd diagClearError $Slot

			export StartTime=`/bin/date \+\%s`
		else
			export StartTime=`getBladeParam $Slot START_TIME`
			# Check burninerrlog to see if there were any fails since we
			# have started. There could be fails on the test that was
			# interupted during a power cycle. We want to tag a blade as
			# fail even if the test was interupted.
			get_any_errors
			if [ -f /tmp/error_stat_$Slot ]
			then
				rm -f /tmp/error_stat_$Slot
				CumulativeStatus=`expr $CumulativeStatus + 1`
			fi
			# archer:
			#if [ "`/sbin/bootenv | /usr/bin/grep BadRootDev`" != "" ]
			#then
			#	$LogCmd $LogFile "Found BadRootDev in bootenv"
			#fi		
		fi

		#
		# Get the user port list. This MUST be after the
		# diagClearError on the first run.
		# 
		# archer
		#_cmd=`commandPath exec_diag`
		#export UserPorts=`$_cmd diagshow -use_bports 1 | \
		#	 /usr/bin/grep "   OK" | \
		#	 /usr/bin/cut -d " " -f 2 | \
		#	 /usr/bin/grep -v "\-\-" | /usr/bin/sort -n | \
		#	 /usr/bin/xargs /bin/echo`
		export UserPorts=1

		# If we have not executed a command yet, then post
		# start message
		if [ $RunNumber -eq 1 -a $CmdNumber -eq 1 ]
		then
			export CmdNumber=`expr $NumberOfCommands + 1`
			_message="Starting run $_version $_date"
			# Remove double spaces in the message for the forceError command
			_message=`/bin/echo "$_message" | /usr/bin/tr -s " " " "`
			_cmd=`commandPath exec_diag`
			if [ $MultiBlade = TRUE ]
			then
				$_cmd forceError --slot $Slot -severity 4 -message '"'" $Slot $MyName: $_message"'"'
			else
				#$_cmd forceError --slot $Slot -severity 4 -message '"'" $MyName: $_message"'"'
				$_cmd forceError -severity 4 -message '"'" $MyName: $_message"'"'
			fi
			burninMessage "Starting run `/bin/date`"
			if [ "$label" != "-" ]
			then
				burninMessage "Label $label"
			fi
		fi
		# ensure log mode is correct for both the CP and blade
		#_cmd=`commandPath burninLogMode`
		if [ $MultiBlade = TRUE ]
		then
			$_cmd -slot $_cp_slot -mode FIRST_IN
		fi
		$_cmd -slot $Slot -mode FIRST_IN
		saveBladeParams $Slot

		# get setup for quick exit
		trap diagcommon_cleanup INT TERM
	fi
}

##################################
# NAME
#    initializePerRunVariables - initializes the variables
#                                active per burnin run
#
# SYNOPSIS
#    initializePerRunVariables
#
# DESCRIPTION
#    Initializes the variables used to control the per run loop
#    activity, bump run counter, initialize the command counter,
#    and run status to pass.
#
# OPERANDS
#    NONE
##################################
initializePerRunVariables()
{
    #echo "  archer: CmdNumber=$CmdNumber, NumberOfCommands=$NumberOfCommands"
	if [ $CmdNumber -gt $NumberOfCommands ]
	then
	    #echo "  archer: rewind to first cmd"
		export RunStatus=0
		export CmdNumber=1
		export RunTime=`/bin/date \+\%s`
		saveBladeParams $Slot
		#echo "  archer: CmdNumber=$CmdNumber"
	fi
	burninMessage "Begin run $RunNumber of $NumberOfRuns at command $CmdNumber `/bin/date` `get_stats`"
}

##################################
# NAME
#    isACommand - Sorts the command lines from a command entry
#
# SYNOPSIS
#    isACommand
#
# DESCRIPTION
#    This function isACommand() determines if the line in the 
#    $CommandList is an executable, or a comment or other entry. 
#    It assumes that blank lines and lines that start with "#" are 
#    comments or non-executible entries. All other lines are 
#    considered a command.
#
# OPERANDS
#    NONE
##################################
isACommand()
{
	if [ "$*" -a -z "`/bin/echo $* | /usr/bin/grep '#'`" ]
	then
		/bin/echo command
	else
		/bin/echo "other"
	fi
}

##################################
# NAME
#    runBurninCommand - executes the commands from a $CommandList variable
#
# SYNOPSIS
#    runBurninCommand enable command argument ...
#
# DESCRIPTION
# This function runBurninCommand() processes the argument string as a command,
# it updates the command number, and updates the status.
#
# OPERANDS
#  $1 enable  - If the command is to be run
#  $2 command - The command name to run
#  $*         - The command name to run with all its arguments
#
##################################
runBurninCommand()
{
	# get the command from the list, and get the relavent parts
    # archer add for port state
    rm /tmp/figmt.* 2> /dev/null
    rm /tmp/figalb* 2> /dev/null
    rm /tmp/armmt.* 2> /dev/null
	_command=`/bin/echo $CommandList | /usr/bin/cut -d"@" -f$CmdNumber`
	_command_name=`/bin/echo $_command | /usr/bin/cut -d" " -f2`
	_command_args=`/bin/echo $_command | /usr/bin/cut -d" " -f3-`
	_command_name1=`/bin/echo $_command_name  | /usr/bin/sed "s/\// /g"`
	_cnt=`/bin/echo $_command_name1 | /usr/bin/wc -w`
	_command_name2=`/bin/echo $_command_name1 | /usr/bin/cut -d" " -f$_cnt`
	nameForDisplay $_command_name2
	#sleep 1
	:
 	_ports=`/bin/echo $_command_args | /usr/bin/grep -w "UserPorts"`
	_ALL=FALSE
	if { [ "$_command_name" = "spinsilk" ] \
	    || [ "$_command_name" = "backport" ] \
	    || [ "$_command_name" = "spinSilk" ] \
	    || [ "$_command_name" = "backPort" ] ; }
	then
		if [ "$_ports" = "" ]
		then
		    _ALL=TRUE
		fi
	fi
	_cmd_time=`/bin/date \+\%s`
	_var=`eval /bin/echo $_command_name $_command_args`
	_new_var=`eval /bin/echo $_var`
	_enable=`/bin/echo $_command | /usr/bin/cut -d" " -f1`
	_enable=`eval /bin/echo $_enable`
	_val_enable=`eval /bin/echo $_enable`
	if [ "$_val_enable" = "0" ]
	then
		#burninMessage "Command #$CmdNumber Run $DIAG_PKG_PASS - Skip $_new_var `/bin/date` `get_stats`"
		burninMessage "Command #$CmdNumber Run $DIAG_PKG_PASS - Skip $_display_name `/bin/date` `get_stats`"
	else
	    # archer: comment off 1 line
		# shift
		#burninMessage "Command #$CmdNumber Run $DIAG_PKG_PASS - Run $_new_var `/bin/date` `get_stats`"
		burninMessage "Command #$CmdNumber Run $DIAG_PKG_PASS - Run $_display_name `/bin/date` `get_stats`"
		 
		# $_new_var 2>&1 >> $LogFile &
	        rm -f /tmp/cmdlog
		#echo "Command #$CmdNumber Run $DIAG_PKG_PASS - Run $_new_var `/bin/date` `get_stats`" > /tmp/cmdlog
		echo "Command #$CmdNumber Run $DIAG_PKG_PASS - Run $_display_name `/bin/date` `get_stats`" > /tmp/cmdlog
		# Roy commented out the next line
		# $_new_var 2>&1 >> /tmp/cmdlog &
		# Roy add 11 lines to display show command info in the log file
	
		if { [ "$_command_name2" = "tempshow.sh" ] \
		     || [ "$_command_name2" = "voltshow.sh" ] ; }
		then
		   # $_new_var 2>&1 >> $LogFile &
		   $_new_var 2>&1 >> $LogFile 
		   _result1=$?
		else
		   # $_new_var 2>&1 >> /tmp/cmdlog &		
		   $_new_var 2>&1 >> /tmp/cmdlog 		
		   _result1=$?
		fi	

		#check_command_status $_command_name $_cmd_time $_ALL
		check_command_status $_display_name $_cmd_time $_ALL
		# archer add for port state
		# calculatePortState
	fi

	# Increment the number of completed commands
	# command index is already CmdNumber + 1
	CmdNumber=`/bin/expr $CmdNumber + 1`
	TotalCmdNumber=`/bin/expr $TotalCmdNumber + 1`
	if [ $CmdNumber -gt $NumberOfCommands ]
	then
		RunNumber=`/bin/expr $RunNumber + 1`
		# Set for the diag to use in logging
		export DIAG_PKG_PASS=$RunNumber
	fi
	truncate_log
	truncate_log "FAIL_LOG"


	# Flush the data to flash
	/bin/sync

	saveBladeParams $Slot
}

##################################
# NAME
#    burninStatusUpdate - Updates the global variables per burnin run
#
# SYNOPSIS
#    burninStatusUpdate
#
# DESCRIPTION
#    This function burninStateUpdate()handles the status updating 
#    for a burnin script it modifies the CumulativeStatus based
#    on the RunStatus stored in the serial EEPROM of the blade.
#
#    Closing messages are output if this was the last run of burnin, 
#    and the results for this run are stored in the serial EEPROM
#
# OPERANDS
#    NONE
##################################
burninStatusUpdate()
{
	runnum=`getBladeParam $Slot RUN_NUMBER`
	runnum=`/bin/expr $runnum - 1`
	RunStatus=`getBladeParam $Slot RUN_STATUS`
	TotalCmdNumber=`getBladeParam $Slot TOTAL_CMD_NUMBER`
	_current_time=`/bin/date \+\%s`
	_duration=`/bin/expr $_current_time - $RunTime`
	_minute=`/bin/expr $_duration / 60`
	_hour=`/bin/expr $_minute / 60`
	_sec=`/bin/expr $_duration % 60`
	_minute=`/bin/expr $_minute % 60`

	TotalThermal=`/bin/expr $TotalThermal + $Thermal`
	TotalVib=`/bin/expr $TotalVib + $Vib`

	# get existance of any driver errors
	_driver_stat=0
	get_driver_errors before_inc
	if [ -f /tmp/driver_stat_$Slot ]
	then
		rm -f /tmp/driver_stat_$Slot
		_driver_stat=1
	fi
	if [ $RunStatus -eq 0 -a $_driver_stat -eq 0 ]
	then
		_message=PASSED
	else
		_message=FAILED
		CumulativeStatus=`expr $CumulativeStatus + 1`
		_cmd=`commandPath exec_diag`
		if [ $MultiBlade = FALSE ]
		then
			# eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SLOW_BLINK > /dev/null 2>/dev/null
		    #echo " *** burninStatusUpdate() exec_diag --slot $Slot --setled LED_CS_FAIL"
		    echo " *** burninStatusUpdate() exec_diag --setled LED_CS_FAIL"
			eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_FAIL > /dev/null 2>/dev/null
		else
			eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SOLID_ON > /dev/null 2>/dev/null
		fi
		burninMessage "Found error during run $runnum RunStatus $RunStatus driver_stat $_driver_stat"
		burninFailMessage "Found error during run $runnum RunStatus $RunStatus driver_stat $_driver_stat"
	fi
	# burninMessage "END RUN $runnum of $NumberOfRuns $_message `/bin/date` Thermal $TotalThermal Vib $TotalVib took $_hour hr $_minute min $_sec sec ($_hour:$_minute:$_sec)"
	burninMessage "END RUN $runnum of $NumberOfRuns $_message `/bin/date` took $_hour hr $_minute min $_sec sec ($_hour:$_minute:$_sec)"
	#
	# done after message so previous message will be correct
	#
	/bin/sync
}

##################################
# NAME
#    cleanupOnExit - Cleans all temporary files at termination of script
#
# SYNOPSIS
#    cleanupOnExit
#
# DESCRIPTION
#    Removes any working files created by the script, and calls cleanup
#    routine in the main script (my_local_cleanup())
# 
# OPERANDS
#    NONE
##################################
cleanupOnExit()
{
	#
	# Save time data for ending summary
	#
	_run_number=`/bin/expr $RunNumber - 1`
	export DIAG_PKG_PASS=$_run_number
	_current_time=`/bin/date \+\%s`
	_duration=`/bin/expr $_current_time - $StartTime`
	_minute=`/bin/expr $_duration / 60`
	_hour=`/bin/expr $_minute / 60`
	_sec=`/bin/expr $_duration % 60`
	_minute=`/bin/expr $_minute % 60`

    #echo " archer: _current_time=$_current_time, StartTime=$StartTime"
	#echo " archer: _duration=$_duration"
	/bin/echo "$$ COMPLETE" > /tmp/burnin_PID.$FABOS_SWITCHNO.$Slot

	#
	# When all are done, determine status from out testing only if
	# we are still passing. No need to get status if we are already failing
	#
	if [ $CumulativeStatus -eq 0 ]
	then
	    #
	    # When all are done, determine final status
	    # Get status before we start to wait for the other blades to complete
	    #
	    _cmd=`commandPath exec_diag`
	    $_cmd diagshow --slot $Slot -silent 1 -use_bports 1  >> $LogFile
	    _showresult=$?
	    if [ $_showresult = 237 -o $_showresult = 139 ]
	    then
		burninMessage "Known issue diagshow after run complete when cleaning up. showresult $_showresult"
		_showresult=0
	    fi
	    # get existance of any driver errors
	    _driver_stat=0
	    get_driver_errors after_inc
	    if [ -f /tmp/driver_stat_$Slot ]
	    then
		rm -f /tmp/driver_stat_$Slot
		_driver_stat=1
	    fi
	    _showresult=`/bin/expr $_showresult + $_driver_stat`
	    # If we have failed (ever), lite the light and
	    # adjust status
	    if [ $_showresult -ne 0 ]
	    then
		CumulativeStatus=`/bin/expr $CumulativeStatus + 1`
		# --setled only takes effect if the command fails.
		# net result is turn on the LED since test
		# will always fail
		_cmd=`commandPath exec_diag`
		if [ $MultiBlade = FALSE ]
		then
		    #echo " *** cleanupOnExit() exec_diag --slot $Slot --setled LED_CS_FAIL"
		    echo " *** cleanupOnExit() exec_diag --setled LED_CS_FAIL"
			# eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SLOW_BLINK > /dev/null 2>/dev/null
			eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_FAIL > /dev/null 2>/dev/null
		else
		    echo " *** cleanupOnExit() exec_diag --slot $Slot --setled LED_SOLID_ON"
			eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SOLID_ON > /dev/null 2>/dev/null
		fi
		burninMessage "Found error after run complete when cleaning up. showresult $_showresult"
	    fi

	    #
	    # wait for all active burnins to complete to set final status
	    #
	    #
	    # When all are done, determine final status if we are still passing.
	    # No need to get status if we are already failing
	    #
	    if [ $CumulativeStatus -eq 0 ]
	    then
		_some_active=TRUE
		while [ $_some_active = TRUE ]
		do
		    _some_active=FALSE
		    for fil in `ls /tmp/burnin_PID.$FABOS_SWITCHNO.*`
		    do
			_state=`/bin/cat $fil | /usr/bin/cut -d" " -f2`
			if [ "$_state" = ACTIVE ]
			then
			    _some_active=TRUE
			fi
		    done
		    if [ "$_some_active" = "TRUE" ]
		    then
			  sleep 1
		    else
			  #
			  # When all are done, determine final status
			  # Get status one last time before exiting to
			  # allow any ALL test to complete
			  #
			  _cmd=`commandPath exec_diag`
			  $_cmd diagshow --slot $Slot -silent 1 -use_bports 1 >> $LogFile
			  _showresult=$?
			  if [ $_showresult = 237 -o $_showresult = 139 ]
			  then
			    burninMessage "Known issue diagshow after all blades complete their run when cleaning up. showresult $_showresult"
			    _showresult=0
			  fi
			  # get existance of any driver errors
			  _driver_stat=0
			  get_driver_errors after_inc
			  if [ -f /tmp/driver_stat_$Slot ]
			  then
			    rm -f /tmp/driver_stat_$Slot
			    _driver_stat=1
			  fi
			  _showresult=`/bin/expr $_showresult + $_driver_stat`
			  # If we have failed (ever), lite the light and
			  # adjust status
			  if [ $_showresult -ne 0 ]
			  then
			    CumulativeStatus=`/bin/expr $CumulativeStatus + 1`
			    # --setled only takes effect if the command fails.
			    # net result is turn on the LED since test
			    # will always fail
			    _cmd=`commandPath exec_diag`
			    if [ $MultiBlade = FALSE ]
			    then
				eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SLOW_BLINK > /dev/null 2>/dev/null
			    else
				eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_SOLID_ON > /dev/null 2>/dev/null
			    fi
			    burninMessage "Found error after all blades complete their run when cleaning up. showresult $_showresult"
			  fi
		    fi
		done
	    fi
	fi

	#
	# Save final data to blade storage
	#
	if [ "$State" != "DIAGSETCYCLE" ]
	then
		saveBladeParams $Slot
	fi
	#
	# Set exit status now that we are done
	#
	if [ $CumulativeStatus -eq 0 ]
	then
		_cum_state=PASSED
	else
		_cum_state=FAILED
	fi

	#
	# Output a ending summary
	#
	# archer: comment off 2 line and hardcode _version
	#_cmd=`commandPath version`
	#_version=`$_cmd | /usr/bin/grep Fabric | /usr/bin/tr -s " " " " | /usr/bin/cut -d " " -f3`
	_version=1
	_message="$State stat $_cum_state $TotalCmdNumber cmds in $_run_number runs in $_hour hr $_minute min $_sec sec ($_hour:$_minute:$_sec)"
	# Remove double spaces in the message for the forceError command
	_message=`/bin/echo "$_message" | /usr/bin/tr -s " " " "`
	_cmd=`commandPath exec_diag`
	if [ $MultiBlade = TRUE ]
	then
		$_cmd forceError --slot $Slot -severity 4 -message '"'" $Slot $MyName: $_message"'"'
	else
		$_cmd forceError --slot $Slot -severity 4 -message '"'" $MyName: $_message"'"'
	fi
	burninMessage "$_message"
	if [ "$label" != "-" ]
	then
		burninMessage "Label $label"
	fi
	/bin/sync

	#
	# Cleanup anything in the script proper
	#
	my_local_cleanup


	#
	# Indicate to others that we have completed logging activity
	#
	/bin/echo "$$ LOG_COMPLETE" > /tmp/burnin_PID.$FABOS_SWITCHNO.$Slot
	sync

	#
	# Turn off the burnin mode if we are last process running
	#
	_some_active=TRUE
	while [ $_some_active = TRUE ]
	do
		_some_active=FALSE
		for fil in `ls /tmp/burnin_PID.$FABOS_SWITCHNO.*`
		do
			_state=`/bin/cat $fil | /usr/bin/cut -d" " -f2`
			if [ "$_state" != LOG_COMPLETE ]
			then
				_some_active=TRUE
			fi
		done
		if [ "$_some_active" = "TRUE" ]
		then
			sleep 1
		else
		    burninSetLevel 0 > /dev/null
		fi
	done

	#
	# Restore LED control back to EM
	#
	if [ $MultiBlade = FALSE ]
	then
		if [ $CumulativeStatus = 0 ]
		then
		    _cmd=`commandPath exec_diag`
		    # eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_FAST_BLINK > /dev/null 2>/dev/null &
		    #echo " *** cleanupOnExit() exec_diag set_led --slot $Slot --setled  LED_CS_PASS"
		    echo " *** cleanupOnExit() exec_diag set_led --setled  LED_CS_PASS"
		    # eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_PASS > /dev/null 2>/dev/null &
		    eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_CS_PASS > /dev/null 2>/dev/null &
                    echo " *** turn all port leds green"
		    /usr/pkg/diagscripts/cmddir/setled a g f
                    /usr/pkg/diagscripts/cmddir/setportled 0xff a g 1 0 &
        	else
         	    echo " *** turn all port leds yellow"
		    /usr/pkg/diagscripts/cmddir/setled a y f
                    /usr/pkg/diagscripts/cmddir/setportled 0xff a y 1 0 &
		fi
		_cmd=`commandPath switchbeacon`
		$_cmd 1
		
	else
		echo " *** cleanupOnExit() exec_diag set_led --slot $Slot LED_DEFAULT"
		eval $_cmd bogus_test_to_set_led --slot $Slot --setled $LED_DEFAULT > /dev/null 2>/dev/null &
		_cmd=`commandPath bladebeacon`
		$_cmd $Slot 1
	fi
}

##################################
# NAME
#    saveBladeParams - Saves the burnin parameters into non-volitile storage
#
# SYNOPSIS
#    saveBladeParams
#
# DESCRIPTION
#    save all parameters to the serial eeprom 
#    Variables stores in order are:
#
#    1.  State
#    2.  FileName
#    3.  RunNumber
#    4.  RunStatus
#    5.  CumulativeStatus
#    6.  StartTime
#    7.  RunTime
#    8.  TotalThermal
#    9.  TotalVib
#    10. TotalCmdNumber
#
#    These values are stored as a space seperated string. In this form 
#    they can be parsed with the /usr/bin/cut -d" " command to get the individual
#    values when read.
#
# ALSO SEE
#    getBladeParam
#
# OPERANDS
#    NONE
##################################

saveBladeParams()
{
	_cmd=`commandPath saveBladeParameters`
	# echo "$_cmd -slot $1 -offset 0 -data ST:$State SN:$FileName RN:$RunNumber RS:$RunStatus CS:$CumulativeStatus TS:$StartTime TR:$RunTime TT:$TotalThermal TV:$TotalVib TC:$TotalCmdNumber CN:$CmdNumber"
	$_cmd -slot $1 -offset 0 -data "ST:$State SN:$FileName RN:$RunNumber RS:$RunStatus CS:$CumulativeStatus TS:$StartTime TR:$RunTime TT:$TotalThermal TV:$TotalVib TC:$TotalCmdNumber CN:$CmdNumber"
	if [ "$debug_on" != "0" ]
	then
		if [ "$LogFile" != "" ]
		then
			$LogCmd $LogFile "DEBUG saveparam: state $State filename $FileName runnumber $RunNumber runstatus $RunStatus cumstat $CumulativeStatus starttime $StartTime runtime $RunTime totaltime $TotalThermal totalvib $TotalVib totalcmd $TotalCmdNumber cmdnumber $CmdNumber"
		fi
	fi

	# archer add for port state
	_cmd=`commandPath savePortState.sh`
	$_cmd -slot $1 -offset 0 -data "PCS01:$PCS01 PCS02:$PCS02 PCS03:$PCS03 PCS04:$PCS04 PCS05:$PCS05 PCS06:$PCS06 PCS07:$PCS07 PCS08:$PCS08 PCS09:$PCS09 PCS10:$PCS10 PCS11:$PCS11 PCS12:$PCS12 PCS13:$PCS13 PCS14:$PCS14 PCS15:$PCS15 PCS16:$PCS16"

}

##################################
# NAME
#    getBladeParam - returns a burnin parameter from non-volitile storage
#
# SYNOPSIS
#    getBladeParam keyword
#
# DESCRIPTION
#    Get a specific data field from the seeprom. The field to keyword
#    mapping is as follows:
#
#    1.  STATE            State
#    2.  SCRIPT_NAME      FileName
#    3.  RUN_NUMBER       RunNumber
#    4.  RUN_STATUS       RunStatus
#    5.  CUM_STATUS       CumulativeStatus
#    6.  START_TIME       StartTime
#    7.  RUN_TIME         RunTime
#    8.  TEMP_CYCLE       TotalThermal
#    9.  VIB_CYCLE        TotalVib
#    10. TOTAL_CMD_NUMBER TotalCmdNumber
#    11. CMD_NUMBER       CmdNumber
#
#    The entire value string is extracrted from non-volitile storage,
#    and parsed for the specified field value. If the keyword is not
#    one of the eleven above, the string invalid parameter is returned
#
#    This function works in concert with saveBladeParams().
#
# OPERANDS
#    $1 slot        Slot to access
#    $2 keyword     Named field of a value desired
#
##################################
getBladeParam()
{
	gBP_result=0
	_cmd=`commandPath getBladeParameters`
	BladeParameters=`$_cmd -slot $1`
	if [ "$debug_on" != "0" ]
	then
		if [ "$LogFile" != "" ]
		then
			$LogCmd $LogFile "DEBUG getparam - $BladeParameters"
		fi
	fi

	#
	# Start by looking in the default position for the data.
	#
	case $2 in
	"STATE")
		fld_str="ST"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f1`
		;;
	"SCRIPT_NAME")
		fld_str="SN"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f2`
		;;
	"RUN_NUMBER")
		fld_str="RN"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f3`
		;;
	"RUN_STATUS")
		fld_str="RS"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f4`
		;;
	"CUM_STATUS")
		fld_str="CS"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f5`
		;;
	"START_TIME")
		fld_str="TS"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f6`
		;;
	"RUN_TIME")
		fld_str="TR"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f7`
		;;
	"TEMP_CYCLE")
		fld_str="TT"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f8`
		;;
	"VIB_CYCLE")
		fld_str="TV"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f9`
		;;
	"TOTAL_CMD_NUMBER")
		fld_str="TC"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f10`
		;;
	"CMD_NUMBER")
		fld_str="CN"
		fld_result=`/bin/echo "$BladeParameters" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f11`
		;;
	*)
		fld_str="XX"
		gBP_result=fld_result="invalid parameter"
		;;
	esac

	#
	# Default the field if it is missing
	#
	if [ "$fld_result" = "" ]
	then
		$LogCmd $LogFile "$slot_message $MyName: Missing the $fld_str data"
		case $fld_str in
		"ST")
			gBP_result=ACTIVE;;
		"SN")
			gBP_result=`burninSetScript -show`;;
		"RN")
			gBP_result=1;;
		"RS")
			gBP_result=0;;
		"C")
			gBP_result=0;;
		"TS")
			gBP_result=`/bin/date \+\%s`;;
		"TR")
			gBP_result=`/bin/date \+\%s`;;
		"TT")
			gBP_result=0;;
		"TV")
			gBP_result=0;;
		"TC")
			gBP_result=0;;
		"CN")
			gBP_result=1;;
		"XX")
			gBP_result="invalid"
		esac
	else
		#
		# Make sure the data is the correct field requested.
		#
		field=`/bin/echo $fld_result | /usr/bin/cut -d":" -f1 | /usr/bin/cut -d" " -f2`
		if [ "$field" = "$fld_str" ]
		then
			# We have the correct information, so extract the value.
			gBP_result=`/bin/echo $fld_result | /usr/bin/cut -d":" -f2`
		else
			#
			# Determine how many fields there are.
			#
			max_field=`/bin/echo $BladeParameters | /usr/bin/wc -w | /usr/bin/sed "s/ //g"`
			if [ "$max_field" != "11" ]
			then
				$LogCmd $LogFile "$slot_message $MyName: incorrect bladeparameters: $BladeParameters."
			fi
			_pos=1
			while [ $_pos -le $max_field ]
			do
				field=`/bin/echo $BladeParameters | /usr/bin/cut -d":" -f$_pos | /usr/bin/cut -d" " -f2`
				if [ "$field" = "$fld_str" ]
				then
					gBP_result=`/bin/echo $BladeParameters | /usr/bin/cut -d":" -f$_pos | /usr/bin/cut -d" " -f1`
					break
				fi
			_pos=`expr $_pos + 1`
			done
		fi
	fi
	/bin/echo "$gBP_result"
}

##################################
# NAME
#    getPortState - returns a burnin parameter from non-volitile storage
#
# SYNOPSIS
#    getPortState keyword
#
# DESCRIPTION
#
#    The entire value string is extracrted from non-volitile storage,
#    and parsed for the specified field value. If the keyword is not
#    one of the eleven above, the string invalid parameter is returned
#
#    This function works in concert with savePortState().
#
# OPERANDS
#    $1 slot        Slot to access
#    $2 keyword     Named field of a value desired
#
##################################
getPortState()
{
    #echo "get $2" >> test.log
	gBP_result=0
	_cmd=`commandPath getPortState.sh`
	portState=`$_cmd -slot $1`
	#echo "$portState" >> test.log
	if [ "$debug_on" != "0" ]
	then
		if [ "$LogFile" != "" ]
		then
			$LogCmd $LogFile "DEBUG getparam - $portState"
		fi
	fi

	#
	# Start by looking in the default position for the data.
	#
	case $2 in
	"PCS01")
		fld_str="PCS01"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f1`
		;;
	"PCS02")
		fld_str="PCS02"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f2`
		;;
	"PCS03")
		fld_str="PCS03"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f3`
		;;
	"PCS04")
		fld_str="PCS04"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f4`
		;;
	"PCS05")
		fld_str="PCS05"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f5`
		;;
	"PCS06")
		fld_str="PCS06"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f6`
		;;
	"PCS07")
		fld_str="PCS07"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f7`
		;;
	"PCS08")
		fld_str="PCS08"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f8`
		;;
	"PCS09")
		fld_str="PCS09"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f9`
		;;
	"PCS10")
		fld_str="PCS10"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f10`
		;;
	"PCS11")
		fld_str="PCS11"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f11`
		;;
	"PCS12")
		fld_str="PCS12"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f12`
		;;
	"PCS13")
		fld_str="PCS13"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f13`
		;;	
	"PCS14")
		fld_str="PCS14"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f14`
		;;
	"PCS15")
		fld_str="PCS15"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f15`
		;;
	"PCS16")
		fld_str="PCS16"
		fld_result=`/bin/echo "$portState" | /usr/bin/grep $fld_str | /usr/bin/cut -d" " -f16`
		;;
	*)
		fld_str="XX"
		gBP_result=fld_result="invalid parameter"
		;;
	esac

    #echo "fld_result=$fld_result" >> test.log

	#
	# Default the field if it is missing
	#
	if [ "$fld_result" = "" ]
	then
		$LogCmd $LogFile "$slot_message $MyName: Missing the $fld_str data"
		if [ $fld_str = "XX" ]
		then 
			gBP_result="invalid"
		else
			gBP_result=2
		fi
	else
		#
		# Make sure the data is the correct field requested.
		#
		field=`/bin/echo $fld_result | /usr/bin/cut -d":" -f1 | /usr/bin/cut -d" " -f2`
		#echo "field=$field, fld_str=$fld_str" >> test.log
		if [ "$field" = "$fld_str" ]
		then
			# We have the correct information, so extract the value.
			gBP_result=`/bin/echo $fld_result | /usr/bin/cut -d":" -f2`
		    #echo "gBP_result=$gBP_result" >> test.log
		else
			#
			# Determine how many fields there are.
			#
			max_field=`/bin/echo $BladeParameters | /usr/bin/wc -w | /usr/bin/sed "s/ //g"`
			if [ "$max_field" != "16" ]
			then
				$LogCmd $LogFile "$slot_message $MyName: incorrect port state: $portState."
			fi
			_pos=1
			while [ $_pos -le $max_field ]
			do
				field=`/bin/echo $portState | /usr/bin/cut -d":" -f$_pos | /usr/bin/cut -d" " -f2`
				if [ "$field" = "$fld_str" ]
				then
					gBP_result=`/bin/echo $portState | /usr/bin/cut -d":" -f$_pos | /usr/bin/cut -d" " -f1`
					break
				fi
			_pos=`expr $_pos + 1`
			done
		fi
	fi
	/bin/echo "$gBP_result"
}

##################################
# NAME
#    burninSetName - Set the diagnostics burnin test name.
#
# SYNOPSIS
#    burninSetName name | "-show" slot [ -noupdate ]
#
# DESCRIPTION
#    This command sets the name of the current burnin test.  This value
#    is used in messages to indicate which test was running.
#
#    The mode becomes active as soon as this command is executed.
#    It does not require a reboot to take effect.
#
# OPERANDS
#    The following operands are optional:
#
#       name	<blank>, "-show": The current burnin name will
#		be displayed.  Otherwise the burnin name will
#		be set to the specified string.
#
#       slot	Which slot to update.
#
#   -noupdate  Inhibits the configuration update upon succesfull
#              completion of the script
#
##################################
burninSetName()
{
#	_x=`/bin/expr "$2" : "\([0-9]\+\)"`
	_x=`/bin/expr "$2" : "\([0-9]*\)"`
	if { [ -z "$_x" ] || [ $_x -lt $_def_slot ] || [ $_x -gt 100 ] ; }
	then
		_slot=$_def_slot
	else
	        _slot=$_x
	fi

	#
	# Program customization
	#

	_config_string="diag.mode.burnin.$_slot.name" # config string to update
	if [ `isMultiBlade` = TRUE ]
	then
		_config_name="Slot $_slot burnin name"	# User name of config.
	else
		_config_name="burnin name"	# User name of config.
	fi
	_config_default=""		# default value
	_config_mode=$STRING		# config mode

	#
	# burninname()
	#
	checkForShow "$_config_name" "$_config_string" "$_config_mode" "$_config_default" $1

	setConfig $_config_string $_config_mode "$1"
	_fn=`/bin/echo $1 | /usr/bin/cut -d" " -f2`
	_fn1=`/bin/echo $_fn  | /usr/bin/sed "s/\// /g"`
	_ccnt=`/bin/echo $_fn1 | /usr/bin/wc -w`
	_fn2=`/bin/echo $_fn1 | /usr/bin/cut -d" " -f$_ccnt`
	#/bin/echo "$_config_name is now $1"
	/bin/echo "$_config_name is now $_fn2"

	if [ "$3" != "-noupdate" ]
	then
		updateConfig
	fi
}

##################################
# NAME
#    burninSetLevel - Set the diagnostics burnin level.
#
# SYNOPSIS
#    burninSetLevel [ level | "-show" ] [ -noupdate ]
#
# DESCRIPTION
#    This command selects or displays the burnin level.  When the
#    burnin level is set to a value other than 0, the diagnostics
#    daemon program will perform burnin testing in place of POST 2
#    each time a switch blade is powered on.
#
#    The mode becomes active as soon as this command is executed.
#    It does not require a reboot to take effect.
#
#    When a burnin level other than 0 is selected, the actual behavior
#    is determined by the configuration of the diagnostics daemon and
#    the burnin scripts that are run.
#
#    Note:  This command sets both diag.mode.burnin.level and
#    diag.mode.burnin.
#
# OPERANDS
#    The following operand is optional:
#
#       level		Integer value or "-show".  If level
#			is missing or the string "-show" then
#			the current burnin level will be displayed.
#			If an integer is provided then the burnin
#			level will be set to that value.
#
#                       If no parameter is provided the current
#			debug level setting will be displayed.
#
#   -noupdate  Inhibits the configuration update upon succesfull
#              completion of the script
#
#       -noupdate      
#
# SEE ALSO
#     diagsetburnin, diagresetburnin, setburninscript
#
##################################
burninSetLevel()
{
	#
	# Program customization
	#
	_config_string="diag.mode.burnin.level" # config string to update
	_config_string2="diag.mode.burnin"			# config string to update
	_config_name="Burnin level"	# User name of config.
	_config_default=0		# default value
	_config_mode=$INTEGER		# config mode


	########################
	#
	# burninlevel()
	#

	checkForShow "$_config_name" "$_config_string" "$_config_mode" "$_config_default" $1
	_val=`getValue $1`
	if [ $? != 0 ] ; then exit 3 ; fi

	if [ $_val -lt 0 ] ; then
	err "Burnin level must be >= 0"
	exit 3
	fi

	# set level
	setConfig $_config_string $_config_mode $_val
	# /bin/echo $_config_name is now $_val.

	# set enable
	if [ $_val != 0 ] ; then
	_val=1
	fi
	setConfig $_config_string2 $_config_mode $_val
	if [ "$_val" = "1" ] ; then
	_res=Enabled
	else
	_res=Disabled
	fi
	/bin/echo Burnin mode is $_res.
	if [ "$2" != "-noupdate" ]
	then
		updateConfig
	fi
}
##################################
# NAME
#    burninSetScript - Set diagnostics post/burnin scripts.
#
# SYNOPSIS
#    burninSetScript type event [ path ] [ -noupdate ]
#
# DESCRIPTION
#    This command selects the scripts to be run by the diagnostics
#    daemon for various events.  When the specified event occurs for
#    the specified board type then the script will be run.
#
#
#
#    The mode becomes active as soon as this command is executed.
#    It does not require a reboot to take effect.
#
# OPERANDS
#
#    type      Board type.  Possible values include "CP", "GP", "WAN",
#	       and "SWITCH".  For normal operations on switch blades
#	       "SWITCH" should be specified.
#
#    event     Event type.  Valid settings are "POST1", "POST2" and
#	       "BURNIN"
#
#    path      Path name for script to run.  If this parameter is ommited
#	       or contains the string "-show" then the current setting will
#	       be displayed.
#
#   -noupdate  Inhibits the configuration update upon succesfull
#              completion of the script
#
#
# Program customization
#
##################################
burninSetScript()
{
	_typ=$1
	_event=$2
	_config_string='diag.script.$_typ.$_event' # config string to update
	_config_name='$_event script for $_typ boards'	# User name of config.
	_config_default="-none-"		# default value
	_config_mode=$STRING		# config mode

	#
	# burninscript
	#

	_config_string=`eval /bin/echo $_config_string`
	_config_name=`eval /bin/echo $_config_name`
	checkForShow "$_config_name" "$_config_string" "$_config_mode" "$_config_default" "$3"

	#
	# parse for -h for help
	#

	if [ "$3" = "-h" ] ; then
	   /bin/echo "Usage: diagsetburnin [ script | -current ]"
	   exit 0
	fi

	#
	# Make sure file exists
	#

	_ok=0
		
	for _f in "$3" "$FABOSHOME/share/$3" "$FABOSHOME/sbin/$3" "$home/$3"; do
	if [ -x $_f ] ; then
		_ok=1
		break;
	fi
	done

	if [ $_ok = 0 ] ; then
	   err "$3 is not executable"
	   exit 3
	fi

	#
	# Make sure this is good setting
	#
	_ok=`eval testConfig $_config_string $_config_mode`
	if [ $? != 0 ] ; then exit 3 ; fi
	if [ $_ok = 0 ] ; then
	   /bin/echo "$config_string is not in database."
	   /bin/echo "Are you sure [y/n d:n] ?"
	read _ans
	if [ "$_ans" != "y" ] ; then exit 3 ; fi
	fi

	setConfig $_config_string $_config_mode $_f
	#/bin/echo $_config_name is now $_f
	if [ "$4" != "-noupdate" ]
	then
		updateConfig
	fi
}
##################################
# NAME
#    getNumAvailableScripts - Output the number of scripts that
#                             contain the specified keyword
#
# SYNOPSIS
#    getNumAvailableScripts Keyword [-config | -noconfig ]
#
# DESCRIPTION
#    Output the number of scripts available that support the specified
#    keyword activity. Include the current script if there has been
#    one selected.
#
#    The determination is triggered by the presence of the keyword
#    $1 in the files in $FABOSHOME/share. If there is a variable that
#    holds the current selection, then $2 contains "-config". If there
#    is no config variable then $2 = "-noconfig"
#
# OPERANDS
#    $1 - Keyword to search for
#    $2 - "-config" "-noconfig"
##################################
getNumAvailableScripts()
{
  if [ "$2" = "-config" ]
  then
    /bin/echo "-current" > /tmp/$$.tmp
  fi
#  /usr/bin/grep "$1" /fabos/share/* 2>/dev/null | \
#      /usr/bin/cut -d":" -f1 | \
#      /usr/bin/sort -u | \
#      /usr/bin/grep -v diagcommon | \
#      /usr/bin/sed "s/\/fabos\/share\///g" >> /tmp/$$.tmp

  /usr/bin/grep "$1" /usr/pkg/diagscripts/share/*.sh | \
      /usr/bin/cut -d":" -f1 > /tmp/tmp.sort

      /usr/bin/sort -u /tmp/tmp.sort | \
      /usr/bin/grep -v diagcommon | \
      /usr/bin/sed "s/\/usr\/pkg\/diagscripts\/share\///g" >> /tmp/$$.tmp

  /usr/bin/wc -l /tmp/$$.tmp | \
		  /usr/bin/tr -s " " " " | \
		  /usr/bin/cut -d" " -f2
  /bin/rm -f /tmp/$$.tmp > /dev/null 2>&1
}

##################################
# NAME
#    showAvailableScripts - Output the names of scripts that
#                           contain the specified keyword
#
# SYNOPSIS
#    showAvailableScripts Keyword [ -noconfig | configvar default ]
#
# DESCRIPTION
#    Output a list of the scripts available that support burnin activity.
#    Include the current burnin script if there has been one selected.
#
#    The determination is triggered by the presence of the keyword
#    $1 in the files in $FABOSHOME/share. If there is a variable that
#    holds the current selection, then the variable name is specified
#    in $2 and the default value in $3. The config variables are
#    assumed to be of type $STRING. 
#
#    If there is no config variable then $2 = "-noconfig"
#
# OPERANDS
#    $1 - Keyword to search for
#    $2 - Config variable that contains the current setting 
#	  (if none then "-noconfig")
#    $3 - Defaults value for config variable
##################################
showAvailableScripts()
{
  # Add the EXIT choice
  /bin/echo "EXIT" > /tmp/$$.tmp

  # Add current setting if available
  if [ "$2" = "-noconfig" ]
  then
    _script=""
  else
    _script=`getConfig "$2" $STRING $3`
  fi

  if [ ! -z "$_script" ]
  then
  
    _script1=`/bin/echo $_script  | /usr/bin/sed "s/\// /g"`
    _count1=`/bin/echo $_script1 | /usr/bin/wc -w`
    _script2=`/bin/echo $_script1 | /usr/bin/cut -d" " -f$_count1`  
    /bin/echo "-current \($_script2\)" >> /tmp/$$.tmp
  fi

  # generate list of remaining choices
#  /usr/bin/grep "$1" /fabos/share/* 2>/dev/null | \
#      /usr/bin/cut -d":" -f1 | \
#      /usr/bin/sort -u | \
#      /usr/bin/grep -v diagcommon | \
#      /usr/bin/sed "s/\/fabos\/share\///g" >> /tmp/$$.tmp

  /usr/bin/grep "$1" /usr/pkg/diagscripts/share/*.sh | \
      /usr/bin/cut -d":" -f1 > /tmp/tmp.sort

      /usr/bin/sort -u /tmp/tmp.sort | \
      /usr/bin/grep -v diagcommon | \
      /usr/bin/sed "s/\/usr\/pkg\/diagscripts\/share\///g" >> /tmp/$$.tmp

  # format output as " #) scriptname"
  _num=0
  /bin/cat /tmp/$$.tmp | while read _line
  do
    /bin/echo " $_num) $_line"
    _num=`/bin/expr $_num + 1`
  done
  /bin/rm -f /tmp/$$.tmp > /dev/null 2>&1
}

##################################
# NAME
#    getScriptSelection - Output the name of nth script that
#                         contain the specified keyword
#
# SYNOPSIS
#    getScriptSelection N Keyword [ -noconfig | configvar default ]
#
# DESCRIPTION
#    Output the Nth script available that supports keyworded activity.
#    Include the current burnin script if there has been one selected.
#
#    The determination is triggered by the presence of the keyword
#    $1 in the files in $FABOSHOME/share. If there is a variable that
#    holds the current selection, then the variable name is specified
#    in $2 and the default value in $3. The config variables are
#    assumed to be of type $STRING. 
#
#    If there is no config variable then $2 = "-noconfig"
#
# OPERANDS
#    $1 - Nth selection
#    $2 - Keyword to search for
#    $3 - Config variable that contains the current setting 
#	  (if none then "-noconfig")
#    $4 - Defaults value for config variable
##################################
getScriptSelection()
{
  # Add the EXIT choice
  /bin/echo "EXIT" > /tmp/$$.tmp

  # generate list of script names. Include current if specified
  if [ "$3" = "-noconfig" ]
  then
    _script=""
  else
    _script=`getConfig "$3" $STRING $4`
  fi
  if [ "$_script" != "" ]
  then
    /bin/echo "$_script" >> /tmp/$$.tmp
  fi
#  /usr/bin/grep "$2" /fabos/share/* 2>/dev/null | \
#      /usr/bin/cut -d":" -f1 | \
#      /usr/bin/sort -u | \
#      /usr/bin/grep -v diagcommon | \
#      /usr/bin/sed "s/\/fabos\/share\///g" >> /tmp/$$.tmp
  /usr/bin/grep "$2" /usr/pkg/diagscripts/share/*.sh 2>/dev/null | \
      /usr/bin/cut -d":" -f1 > /tmp/tmp.sort

      /usr/bin/sort -u /tmp/tmp.sort | \
      /usr/bin/grep -v diagcommon | \
      /usr/bin/sed "s/\/usr\/pkg\/diagscripts\/share\///g" >> /tmp/$$.tmp

  # get the max allowable value for N
  _num_choice=`/usr/bin/wc -l /tmp/$$.tmp | \
			   /usr/bin/tr -s " " " " | \
			   /usr/bin/cut -d" " -f2`

  # get the selected choice
  if [ $1 -lt 0 -o $1 -gt $_num_choice ]
  then
    /bin/echo "Invalid"
  else
    _num=0
    /bin/cat /tmp/$$.tmp | while read _line
    do
      if [ $_num -eq $1 ]
      then
        /bin/echo "$_line"
        break
      fi
      _num=`/bin/expr $_num + 1`
    done
  fi
  /bin/rm -f /tmp/$$.tmp > /dev/null 2>&1
}


