#!/bin/sh
#
#
#    Copyright (c) 1996-2001 Brocade Communications Systems, Inc.
#    All rights reserved.
#
#    File name:   switchburnin
#    Module name: diag/scripts
#
#    This file operates the burnin activity.
#
# NAME
#    burnin - Supports three activities
#    1. Set burnin command diagsetsycle for burnin
#    2. Containes the burnin activity list
#    3. Processes the burnin activity
#
# SYNOPSIS
#    switchburnin [ diagsetcycle ]
#
# AVAILABILITY
#    swt_mfg
#
# DESCRIPTION
#    This command will manage the burnin activity. It contains and
#    manages the parameters needed this activity. It also cointains
#    the list of activities to perform during a single burnin run. 
#    It has the processing loop to execute the commands in the list.
#
#    The mode becomes active as soon as this command is executed.
#    It does not require a reboot to take effect.
#
# OPERANDS
#
#    "diagsetcycle"    This operand will trigger activity related to 
#                      editing the avialable parameters active during
#                      the burnin activity. The user will be prompted 
#                      to modify each parameter in the odrer specified 
#                      in the this script. The current value, default 
#                      value, and description of the parameter are 
#                      displayed. If the user does not want to modify 
#                      the value, then a <cr> is recognized as 
#                      "hold current value". Any other value for this
#                      parameter is ignored.
#
################################
# The function create_param_file() is required in this script.
# It is intended to be modified to define the persistent 
# parameters required by the script. It must only be modified
# between the "#Make changes after this line" and 
# "#Make changes above this line".
#
# All entries starting with PARAMDEF will be available in 
# diagsetcycle burnin command. Lines beginning with "PARAMDEF"
# will define parameters that will persistent across power 
# cycles and are available as environment variables during the
# duration of the script.
#
# A PARAMDEF line can not contain leading spaces. The parameters 
# will appear for editing in the same order as they are listed.
# Each PARAMDEF entry contain several parts seperated by a 
# single space character. The information is interputed in a 
# specific order. The parts are:
#   1. keyword (PARAMDEF) No leading spaces are allowed.
#   2. variable name (single word) space seperated
#   3. default value for parameter
#   4. type of variable ($STRING, $INTEGER)
#   5. minimum value (only for integer, NA if not applicable)
#   6. maximum value (only for integer, NA if not applicable)
#   7. description (rest of the line until "\n")
#
# Any line not starting with PARAMDEF is considered a comment, and 
# is not processed.
#
# The following is an example of declaring a variable to use 
# in diagsetcycle to control the -nmegs value for crossPortTest.
# It is then used in the command definition as a variable derived 
# from the shell.
# Example:
#
#  ------------------------------------- 1 definition
#  |        ---------------------------- 2 variable name
#  |        |     ---------------------- 3 default value
#  |        |     |   ------------------ 4 type
#  |        |     |   |        --------- 5 min
#  |        |     |   |        | ------- 6 max
#  |        |     |   |        | |  ---- 7 comment
#  |        |     |   |        | |  |
#  |        |     |   |        | |  |
#  |        |     |   |        | |  |
#  v        v     v   v        v v  v
#  PARAMDEF nmegs 150 $INTEGER 0 NA Million frames for crossPortTest
#          crossporttest -nmegs \$nmegs -lb_mode 1
#
##################################

create_param_file()
{
/bin/cat << EOF
#Make changes after this line
PARAMDEF log_length 1 $INTEGER 1 20 log file max length (1M unit)
PARAMDEF number_of_runs 1 $INTEGER 0 NA number of passes of burnin
#PARAMDEF volt_show_run 1 $INTEGER 0 NA number of test for reading voltage
#PARAMDEF asic_rev_run 1 $INTEGER 0 NA number of test for reading asic revision 
#PARAMDEF temp_show_run 1 $INTEGER 0 NA number of test for reading temperature 
#PARAMDEF sfp_show_run 1 $INTEGER 0 NA number of sfpshow test
#PARAMDEF sfp_show_index 16 $INTEGER 0 16 sfp index (0-15, 16:all)
#PARAMDEF ps_show_run 1 $INTEGER 0 NA number of psshow test
#PARAMDEF seprom_test_run 1 $INTEGER 0 NA number of seprom test
#PARAMDEF fan_set_run 1 $INTEGER 0 NA number of set fan speed test
#PARAMDEF fan_show_run 1 $INTEGER 0 NA number of read fan tray test
PARAMDEF figmem_enable 1 $INTEGER 0 1 figero port memory test (0: off, 1: on) 
PARAMDEF figmem_figero_id 16 $INTEGER 0 16 figero id (0 - 15, 16: all)
PARAMDEF figmem_mem_blk 0 $INTEGER 0 9 port memory block (1-9, 0: all)
PARAMDEF figarm_enable 1 $INTEGER 0 1 figero arm memory test (0: off, 1: on) 
PARAMDEF figarm_figero_id 16 $INTEGER 0 16 figero id (0 - 15, 16: all)
PARAMDEF figarm_mem_blk 0 $INTEGER 0 2 arm memory block (1-2, 0: all)
PARAMDEF cellomt_enable 1 $INTEGER 0 1 cello memory test (0: off, 1: on) 
PARAMDEF cellomt_def_pat 0 $INTEGER 0 1 test data pattern (0: hash, 1: inc)
PARAMDEF cellopt_pkt_ct 100000 $INTEGER 0 NA packet number for celloporttest
PARAMDEF gmactst_pkt_ct 100000 $INTEGER 0 500000 packet number for gmac2brigetest
PARAMDEF gmactst_burst_len 1024 $INTEGER 1 1024 gmac2bridgetest burst len
PARAMDEF portlb_eth_cnt 100000 $INTEGER 0 NA figero port loopback count
PARAMDEF portlb_eth_fig 16 $INTEGER 0 16 figero id (0-15: figero 16 all) 
PARAMDEF portlb_eth_lb 0 $INTEGER 0 1 figero lpbk type (0: int, 1: ext) 
PARAMDEF portlb_fc1_cnt 100000 $INTEGER 0 NA figero port loopback count
PARAMDEF portlb_fc1_fig 16 $INTEGER 0 16 figero id (0-15: figero 16 all) 
PARAMDEF portlb_fc1_lb 0 $INTEGER 0 1 figero lpbk type (0: int, 1: ext) 
PARAMDEF portlb_fc2_cnt 100000 $INTEGER 0 NA figero port loopback count
PARAMDEF portlb_fc2_fig 16 $INTEGER 0 16 figero id (0-15: figero 16 all) 
PARAMDEF portlb_fc2_lb 0 $INTEGER 0 1 figero lpbk type (0: int, 1: ext) 
PARAMDEF spsilk_eth_cnt 100000 $INTEGER 0 NA spinsilk count
PARAMDEF spsilk_eth_fig 16 $INTEGER 0 16 figero id (0-15: figero 16 all) 
PARAMDEF spsilk_eth_lb 4 $INTEGER 2 6 spinsilk lpbk (2-4: int, 5-6: ext) 
PARAMDEF spsilk_fc1_cnt 100000 $INTEGER 0 NA spinsilk count
PARAMDEF spsilk_fc1_fig 16 $INTEGER 0 16 figero id (0-15: figero 16 all) 
PARAMDEF spsilk_fc1_lb 4 $INTEGER 2 6 spinsilk lpbk (2-4: int, 5-6: ext) 
PARAMDEF spsilk_fc2_cnt 100000 $INTEGER 0 NA spinsilk count
PARAMDEF spsilk_fc2_fig 16 $INTEGER 0 16 figero id (0-15: figero 16 all) 
PARAMDEF spsilk_fc2_lb 4 $INTEGER 2 6 spinsilk lpbk (2-4: int, 5-6: ext) 
#Make changes above this line
EOF
}

##################################
# The function create_command_file() is required in this script.
# It is the list of commands to execute during each burnin pass.
# The commands will be executed in order from top to bottom.  It
# must only be modified between the "#Make changes after this line"
# and "#Make changes above this line".
#
# A command is defined as any command line string that can be
# executed from the telnet prompt preceeded by a indicator of if the
# command is enabled. These include fabos commands, scripts,
# diagnostics, and internal functions within this script.
#
# Example:
#
#  ----------------------------------------- 1 enable (0=disable)
#  |            ---------------------------- 2 command
#  |            |                      ----- 3 arguments
#  |            |                      |
#  |            |                      |
#  |            |                      |
#  v            v                      v
#  \$tbr_passes turboramtest -passcnt \$tbr_passes
#
# The enable can be hardcoded "0" (off) or (1) ON, or it can be a
# PARAMDEF. The paramdef is used in the example.
#
# The return status of the command is included in the overall 
# status of the the burnin pass.  The script assumes that a 
# command exit status of 0 indicates PASS, and any other value
# is a fail. If the commands do not return values in this way,
# then a wrapper function in this script must be added that serves 
# to translate the command exit status in the the 0=PASS, !0=FAIL
# status. This wrapper function would be placed in the command list.
#
# The PARAMDEF names can be used in place of arguments to the 
# commands (-lb_mode, -nmegs, ...). They can also be used for
# any variable within the run processing. For example the first
# one in the list can be the number of burnin passes to complete,
# or on which pass to run a command.
#
# Regular shell variables can also be used, however they are not 
# maintained across power cycles with the exception of $RunNumber,
# $RunStatus $CumulativeStatus $State. These are used by the 
# burnin script and are available for use.
#
# CommandNumber    - indicates the line of command file being processed.
#                    Incremented during runBurninCommand()
# RunNumber        - the number of burnin passes activated.
# RunStatus        - 0/1 PASS/FAIL status of active run.
# CumulativeStatus - 0/1 PASS/FAIL status of the all active runs.
# NumberOfRuns     - number of burnin passes to complete. (PARAMDEF)
# State            - ACTIVE (continue running burnin)
#                    COMPLETE (burnin not started)
# LogFile          - Path and file containing log of command and shell output
# UserFile         - File name for this scripts purpose
#
# (NOTE: UserFile is only a file name, and does not contain a path. If it is
#  to be used in this script, it needs path set local to this script.)
#
# The entire path to the Linux commands must be specified. This is due
# to the context inwhich this script executes. This is not required for 
# shell internals like eval. It is needed for expr. Please type 
# which <command> to get the path to the command.
#
# When using variable references in a command argument, the "$"
# in the reference must be proceeded by a "\" to prevent the 
# shell from inturputing the "$". Also make sure the referenced variable
# is exported. The export of PARAMDEF variables is automatic.
##################################

create_command_file()
{
/bin/cat << EOF
#Make changes after this line

#\$volt_show_run /usr/pkg/diagscripts/cmddir/voltshow.sh \$volt_show_run 0

#\$asic_rev_run /usr/pkg/diagscripts/cmddir/asicshow.sh  \$asic_rev_run 

#\$temp_show_run /usr/pkg/diagscripts/cmddir/tempshow.sh  \$temp_show_run 

#\$sfp_show_run /usr/pkg/diagscripts/cmddir/sfpshow.sh \$sfp_show_run \$sfp_show_index

#\$ps_show_run /usr/pkg/diagscripts/cmddir/psshow.sh \$ps_show_run 

#\$seprom_test_run /usr/pkg/diagscripts/cmddir/sepromtest.sh  \$seprom_test_run

#\$fan_set_run /usr/pkg/diagscripts/cmddir/setfanspeed.sh  \$fan_set_run \$RunNumber 

#\$fan_show_run /usr/pkg/diagscripts/cmddir/fanshow.sh  \$fan_show_run 

\$figmem_enable /usr/pkg/diagscripts/cmddir/figmem.sh \$figmem_figero_id \$figmem_mem_blk 1

\$figarm_enable /usr/pkg/diagscripts/cmddir/figarm.sh \$figarm_figero_id \$figarm_mem_blk 1

\$cellomt_enable /usr/pkg/diagscripts/cmddir/cellomt.sh \$cellomt_def_pat 

\$cellopt_pkt_ct /usr/pkg/diagscripts/cmddir/cellopt.sh  \$cellopt_pkt_ct

\$gmactst_pkt_ct /usr/pkg/diagscripts/cmddir/gmactst.sh  \$gmactst_pkt_ct \$gmactst_burst_len 1

\$portlb_eth_cnt /usr/pkg/diagscripts/cmddir/portlb_eth.sh \$portlb_eth_fig  \$portlb_eth_cnt \$portlb_eth_lb

\$portlb_fc1_cnt /usr/pkg/diagscripts/cmddir/portlb_fc1.sh \$portlb_fc1_fig  \$portlb_fc1_cnt \$portlb_fc1_lb 

\$portlb_fc2_cnt /usr/pkg/diagscripts/cmddir/portlb_fc2.sh \$portlb_fc2_fig  \$portlb_fc2_cnt \$portlb_fc2_lb

\$spsilk_eth_cnt /usr/pkg/diagscripts/cmddir/spinsilk_eth.sh \$spsilk_eth_fig  \$spsilk_eth_cnt \$spsilk_eth_lb

\$spsilk_fc1_cnt /usr/pkg/diagscripts/cmddir/spinsilk_fc1.sh \$spsilk_fc1_fig  \$spsilk_fc1_cnt \$spsilk_fc1_lb 

\$spsilk_fc2_cnt /usr/pkg/diagscripts/cmddir/spinsilk_fc2.sh \$spsilk_fc2_fig  \$spsilk_fc2_cnt \$spsilk_fc2_lb

#Make changes above this line
EOF
}

BEFORE_RUN()
{
  #
  # Adjust the lb_mode values based in min_lb_mode
  #
#  ptlb_lb_mode=2
#  xpt_lb_mode=1
#  slkser_lb_mode=2
#  slkcbl_lb_mode=1

#  if [ $ptlb_lb_mode -lt $min_lb_mode ]
#  then
#    burninMessage "BEFORE_RUN: Limiting lb_mode to $min_lb_mode portloopbacktest."
#    ptlb_lb_mode=$min_lb_mode
#  fi

#  if [ $xpt_lb_mode -lt $min_lb_mode ]
#  then
#    burninMessage "BEFORE_RUN: Limiting lb_mode to $min_lb_mode for crossporttest."
#    xpt_lb_mode=$min_lb_mode
#  fi

#  if [ $slkser_lb_mode -lt $min_lb_mode ]
#  then
#    burninMessage "BEFORE_RUN: Limiting lb_mode to $min_lb_mode spinsilk Serdes."
#    slkser_lb_mode=$min_lb_mode
#  fi

#  if [ $slkcbl_lb_mode -lt $min_lb_mode ]
#  then
#    burninMessage "BEFORE_RUN: Limiting lb_mode to $min_lb_mode spinsilk Cable."
#    slkcbl_lb_mode=$min_lb_mode
#  fi
}

my_local_cleanup() 
{
#  /bin/echo " $Slot $MyName: Done with cleanup"
  /bin/echo "$MyName: Done with cleanup"
}

##################################
# Main body of script
# DIAGSETCYCLE_CAPABLE
##################################
# Load common functions
# Should be first to ensure the library 
# functions are available for use
##################################
export DIAG_PKG_STR="1N"
home="/usr/pkg/diagscripts/share"
util="diagcommon.sh"
ok=0
for f in "./$util" "$FABOSHOME/share/$util" "$home/$util" ; do
	if [ -r $f ] ; then
		. $f
		ok=1
		break;
	fi
done
if [ $ok -ne 1 ] ; then
	err "Could not locate $util"
	exit 3
fi

#
# get sys info for multi blade
#
multiBlade=`isMultiBlade`
if [ $multiBlade = TRUE ]
then
     export syntax="$0 -slot [slot] burninScript"
else
     export syntax="$0 burninScript"
fi

##################################
# Check if it is OK to begin the run burnin
##################################

checkBurninState $*

##################################
# MAIN PROCCESS LOOP for the commands
##################################

# echo " archer: RunNumber=$RunNumber, NumberOfRuns=$NumberOfRuns"
while [ "$RunNumber" -le "$NumberOfRuns" ]
do

  # printPortState
  # archer add for port state
  rm /tmp/figmt.* 2> /dev/null
  rm /tmp/figalb.* 2> /dev/null
  rm /tmp/armmt.* 2> /dev/null

  # echo " archer: call initializePerRunVariables()"
  ###################################
  # initialize run and indicate which pass we are beginning
  ###################################
  initializePerRunVariables
  
  # echo " archer: call BEFORE_RUN()"
  BEFORE_RUN
  ###################################
  # Begin processing the command file
  ###################################  
  while [ "$CmdNumber" -le "$NumberOfCommands" ]
  do

    # echo " archer: call runBurninCommand()"
    runBurninCommand

  done  
  
  ###################################
  # Update the status at the end of the pass
  ###################################
  # echo " archer: call burninStatusUpdate()"
  burninStatusUpdate
    
done


State=COMPLETED

cleanupOnExit

##################################################
# Disable diag mode at the end of the script (Roy)
##################################################
/usr/pkg/sbin/diagpost 1
/usr/pkg/diagscripts/cmddir/diagmode "normal"
echo " "
echo "Diagnostic tests successfully completed."
echo "Press enter key to reboot and resume normal operation. "
echo " "

while read _answer
do
	/usr/pkg/sbin/reboot
done    

exit $CumulativeStatus
